# -*- coding:utf-8 -*-
# @time:2023/2/1810:31
# @author:LX
# @file:controlType.py
# @software:PyCharm

__all__ = ["getStyleLists","getStyleCommentLists"]

STYLE_LIB = {
    ("QPushButton",):{"QPushButton":"/*按钮*/",
                       "QPushButton:hover":"/*鼠标放在按钮上时的样式*/",
                       "QPushButton:pressed":"/*按钮按下时的样式*/",
                       "QPushButton::menu-indicator":"/*菜单指示器子控件(在菜单栏时的样式)*/",
                       "QPushButton:open":"/*按钮在菜单打开时的样式*/"},
    ("QLabel",): {"QLabel": "/*标签*/",
                  "QLabel:hover": "/*鼠标放在标签上时的样式*/"
               },
    ("QLineEdit",):{
        "QLineEdit":"/**/",
        "QLineEdit:read-only":"/*只读时读样式*/"
    },
    ("QWidget",):{
        "QWidget":"/**/"
    },
    ("QComboBox",): {"QComboBox": "/*下拉框*/",
                  "QComboBox:!editable": "/*编辑框样式*/",
                  "QComboBox:editable": "/*编辑框样式(需要将editable设置为真才生效,内容可编辑)*/",
                  "QComboBox::drop-down": "/*下拉按钮样式*/",
                  "QComboBox::drop-down:editable": "/*下拉按钮样式(需要将editable设置为真才生效,内容可编辑)*/",
                  "QComboBox:!editable:on": "/*拉下列表展开时,编辑框样式*/",
                  "QComboBox::drop-down:!editable:on": "/*拉下列表展开时,下拉按钮样式*/",
                  "QComboBox:on": "/*拉下列表展开时,文本的样式*/",
                  "QComboBox::down-arrow": "按钮里的图标样式",
                  "QComboBox::down-arrow:on": "/*拉下列表展开时，移动箭头*/"
                  },
    ("QCheckBox",): {"QCheckBox": "/*复选框,将tristate设置为真时有三种状态(选中,未选中,待选中)*/",
                  "QCheckBox::indicator": "/*文本旁边的标志样式*/",
                  "QCheckBox::indicator:unchecked": "/*文本旁边的标志没有选中时的样式*/",
                  "QCheckBox::indicator:unchecked:hover": "/*文本旁边的标志没有选中时的鼠标放上去时的样式*/",
                  "QCheckBox::indicator:unchecked:pressed": "/*文本旁边的标志没有选中按下时一瞬间的样式*/",
                  "QCheckBox::indicator:checked": "/*文本旁边的标志选中时的样式*/",
                  "QCheckBox::indicator:checked:hover": "/*文本旁边的标志选中时的鼠标放上去时的样式*/",
                  "QCheckBox::indicator:checked:pressed": "/*文本旁边的标志选中按下时一瞬间的样式*/",
                  "QCheckBox::indicator:indeterminate:hover": "/*文本旁边的标志待选中时的鼠标放上去时的样式(需要将tristate设置为真才生效)*/",
                  "QCheckBox::indicator:indeterminate:pressed": "/*文本旁边的标志待选中按下时一瞬间的样式(需要将tristate设置为真才生效)*/"},
    ("QGroupBox",): {"QGroupBox": "/*组合框(与QCheckBox样式相似)*/",
                  "QGroupBox::title": "/*标题样式*/",
                  "QGroupBox::indicator": "/*标题旁边控件样式(需要将checkable)设置为真才生效*/",
                  "QGroupBox::indicator:unchecked": "/*标题旁边控件没有选中时的样式(需要将checkable)设置为真才生效)*/"
                  },
    ("QListView",): {"QListView": "/*列表视图*/",
                  "QListView::item:alternate": "/**/",
                  "QListView::item:selected": "/**/",
                  "QListView::item:selected:!active": "/**/",
                  "QListView::item:selected:active": "/**/",
                  "QListView::item:hover": "/**/"
                  },
    ("QListWidget",): {"QListWidget": "/*列表视图*/",
                       "QListWidget::item:alternate": "/**/",
                       "QListWidget::item:selected": "/**/",
                       "QListWidget::item:selected:!active": "/**/",
                       "QListWidget::item:selected:active": "/**/",
                       "QListWidget::item:hover": "/**/"
                       },
    ("QProgressBar",): {"QProgressBar": "/*进度条*/",
                     "QProgressBar::chunk": "进度条中间颜色区域样式"},
    ("QScrollBar",): {"QScrollBar": '''
            /*滚动条样式
            QScrollBar 指所有滚动条样式
            QScrollBar:horizontal 水平
            QScrollBar:vertical  垂直
            */
            ''',
                   "QScrollBar:horizontal": "/*水平滚动条样式*/",
                   "QScrollBar::handle:horizontal": "/*水平滚动条中手柄的样式*/",
                   "QScrollBar::add-line:horizontal": "/*水平滚动条最右边按钮样式*/",
                   "QScrollBar::sub-line:horizontal": "/*水平滚动条最左边按钮样式*/",
                   "QScrollBar:vertical": "/**/",
                   "QScrollBar::handle:vertical": "/**/",
                   "QScrollBar::add-line:vertical": "/**/",
                   "QScrollBar::sub-line:vertical": "/**/"},
    ("QSlider",):{"QSlider":
                    '''
                    /*
                    滑动条
                    QSlider 指所有滑动条
                    还有 horizontal vertical
                    */
                    ''',
                   "QSlider::groove:horizontal":"/*水平凹槽样式*/",
                   "QSlider::handle:horizontal":"/*水平手柄样式*/",
                   "QSlider::add-page:horizontal":"/*更改手柄前后滑块部分的样式*/",
                   "QSlider::sub-page:horizontal":"/*更改手柄前后滑块部分的样式*/",
                   "QSlider::groove:vertical": "/**/",
                   "QSlider::handle:vertical": "/**/",
                   "QSlider::add-page:vertical": "/**/",
                   "QSlider::sub-page:vertical": "/**/"
                   },
    ("QSpinBox",):{"QSpinBox":"/*微调框*/",
                    "QSpinBox::up-button":"/*上按钮样式*/",
                    "QSpinBox::up-button:hover":"鼠标放在上按钮时的样式",
                    "QSpinBox::up-button:pressed":"鼠标按下 下按钮时的样式",
                    "QSpinBox::up-arrow":"上按钮里小箭头样式",
                    "QSpinBox::down-button":"/*下按钮样式*/",
                    },
    ("QTabWidget",):{"QTabWidget":
                        '''
                        /*
                        标签窗口
                        好用的属性设置
                        documentMode 文档模式
                        tabsCloseable 标签按钮上出现关闭标志
                        movable 标签可移动
                        */
                        ''',
                      "QTabWidget::pane":"/*标签下面框架的样式*/",
                      "QTabBar::tab":"/*标签样式*/",
                      "QTabWidget::tab-bar":"/*标签栏样式(设置颜色无效)*/",
                      "QTabBar::tab:hover":"/*鼠标放在标签上时的样式*/",
                      "QTabBar::tab:selected":"/*标签被选择时的样式*/",
                      "QTabBar::tab:!selected":"/*标签没有被选择时的样式*/",
                      "QTabBar::close-button":"/*关闭按钮的样式(需要将tabsCloseable设置为真才生效)*/",
                      "QTabBar::close-button:hover":"/*鼠标放在关闭按钮上时的样式(需要将tabsCloseable设置为真才生效)*/"
                      },
    ("QTableView",):{"QTableView":"/*表格视图*/",
                      "QTableView QTableCornerButton::section":"/*角落部件样式*/"
                      },
    ("QTreeView",):{"QTreeView":"/*树视图*/",
                     "QTreeView::item":"/**/",
                     "QTreeView::item:hover":"/**/",
                     "QTreeView::item:selected":"/**/",
                     "QTreeView::item:selected:active":"/**/",
                     "QTreeView::item:selected:!active":"/**/",
                     "QTreeView::branch":"/*分支样式*/"},
}


def getStyles(key):
    if isinstance(key,str):
        key = key,
    return STYLE_LIB[key]


# 返回可操作的样式列表
def getStyleLists(key)->list:
    return list(getStyles(key).keys())


# 返回可操作的样式列表说明
def getStyleCommentLists(key)->list:
    return list(getStyles(key).values())


# 融合两个样式列表
def getMergeStyles(style1:list,style2:list)->list:
    return list(set(style1) | set(style2))


# print(getMergeStyles(["QPushButton"],["QPushButton","QPushButton:hover"]))



# -*- coding:utf-8 -*-
# @time:2023/3/1418:29
# @author:LX
# @file:customAniTest.py
# @software:PyCharm
import sys
from PyQt5.QtWidgets import QApplication, QWidget
from PyQt5.QtGui import QPainter, QColor
from PyQt5.QtCore import Qt, QAbstractAnimation


class MyAnimation(QAbstractAnimation):
    def __init__(self, widget):
        super().__init__()
        self.widget = widget
        self.color = QColor(255, 0, 0)
        self.start_value = 0
        self.end_value = 100
        self._duration = 0

    def updateState(self, newState: 'QAbstractAnimation.State', oldState: 'QAbstractAnimation.State') -> None:
        print(newState, oldState)
        super(MyAnimation, self).updateState(newState, oldState)

    def updateCurrentTime(self, currentTime):
        value = self.start_value + (self.end_value - self.start_value) * currentTime / self.duration()
        self.widget.set_value(value)

    def setStartValue(self, value):
        self.start_value = value

    def setEndValue(self, value):
        self.end_value = value

    def setDuration(self, duration):
        self._duration = duration

    def currentValue(self):
        return self.widget.value()

    def state(self):
        pass

    def start(self, policy=QAbstractAnimation.DeleteWhenStopped):
        super().start(policy)

    def stop(self):
        super().stop()

    def duration(self) -> int:
        return self._duration


class MyWidget(QWidget):
    def __init__(self):
        super().__init__()
        self.setGeometry(100, 100, 800, 400)
        self.value = 0

    def paintEvent(self, event):
        painter = QPainter(self)
        painter.setBrush(QColor(255, 255, 255))
        painter.drawRect(0, 0, self.width(), self.height())
        painter.setBrush(QColor(0, 0, 0))
        painter.drawRect(0, 0, int(self.width() * self.value / 100), self.height())

    def set_value(self, value):
        self.value = value
        self.update()


if __name__ == '__main__':
    app = QApplication(sys.argv)
    w = MyWidget()
    animation = MyAnimation(w)
    animation.setDuration(1000)
    animation.setStartValue(0)
    animation.setEndValue(100)
    animation.start()
    w.show()
    sys.exit(app.exec_())



# -*- coding:utf-8 -*-
# @time:2023/5/2718:58
# @author:LX
# @file:palettetools.py
# @software:PyCharm

from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QWidget,
    QVBoxLayout,
    QHBoxLayout,
    QPushButton,
    Signal,
    QLabel,
    QLineEdit,
    QPainter,
    QLinearGradient,
    QSpacerItem,
    QSizePolicy,
    Qt
)

from PyQtGuiLib.core.palettes.paletteTools.paletteToolUI import (
    PaletteToolsUI,
    PureColorOperationUI,
    LinearOperationUI,
    RadialOperationUI,
    ConicalOperationUI,
    Handle_pure,
    Handle_Linear,
    Handle_Radial,
    Handle_Conical,
    G_Mode_Pad,
    G_Mode_Repeat,
    G_Mode_Reflect
)

from PyQtGuiLib.core.palettes.paletteTools.area import PureColorWidget,Linear,Radial,Conical


class PaletteTools(PaletteToolsUI):
    clickStrColor = Signal(str)
    clickSolidColor = Signal(str)  # 这个信号需要开启才能用

    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

        self.isRealTimeSignal = False

        self.pureColorOperation = PureColorOperationUI()
        self.linearOperation = LinearOperationUI()
        self.radialOperation = RadialOperationUI()
        self.conicalOperation = ConicalOperationUI()
        self.addOperationWidget(self.pureColorOperation)
        self.addOperationWidget(self.linearOperation)
        self.addOperationWidget(self.radialOperation)
        self.addOperationWidget(self.conicalOperation)

        self.pureColorWidget = PureColorWidget()
        self.linearWidget = Linear()
        self.radialWidget = Radial()
        self.conicalWidget = Conical()

        self.addColorWidget(self.pureColorWidget)
        self.addColorWidget(self.linearWidget)
        self.addColorWidget(self.radialWidget)
        self.addColorWidget(self.conicalWidget)

        self.state_action_bar.clicked.connect(self.setCurrentIndex)
        self.gm_action_bar.clicked.connect(self.switchSpread_event)
        self.it_action_bar.switchClicked.connect(self.hide_hand_event)

        self.pureColorWidget.rgbaChange.connect(self.it_action_bar.updateHexView)
        self.pureColorWidget.rgbaChange.connect(self.pureColorOperation.updateRGB)

        self.it_action_bar.strawColored.connect(self.pureColorOperation.updateRGB)
        self.it_action_bar.strawColored.connect(self.pureColorWidget.colorbar.updateBgColor)  # 吸管颜色同步的纯色界面

        def __updateHexView():
            color = self.pureColorWidget.colorbar.getColor()
            self.it_action_bar.updateHexView(color)
            self.pureColorOperation.updateRGB(color)

        self.pureColorWidget.hsvRgbaChange.connect(__updateHexView)

        #
        self.pureColorOperation.clickColor.connect(lambda :self.sendStrColor(Handle_pure,None))
        self.linearOperation.clickQSS.connect(lambda :self.sendStrColor(Handle_Linear,self.linearWidget))
        self.radialOperation.clickQSS.connect(lambda :self.sendStrColor(Handle_Radial,self.radialWidget))
        self.conicalOperation.clickQSS.connect(lambda :self.sendStrColor(Handle_Conical,self.conicalWidget))

    # 开启实时信号,默认不启用
    def setEnableRealTimeSignal(self,b:bool):
        if self.isRealTimeSignal is False and b:
            # 实时信号
            self.pureColorWidget.rgbaChange.connect(
                lambda color: self.clickSolidColor.emit("rgba({},{},{},{})".format(*color.getRgb())))
            self.pureColorWidget.hsvRgbaChange.connect(
                lambda color: self.clickSolidColor.emit("rgba({},{},{},{})".format(*color.getRgb())))
            #
            for gobj in [self.linearWidget,self.radialWidget,self.conicalWidget]:
                gobj.qssed.connect(lambda qss: self.clickSolidColor.emit(qss))
            self.isRealTimeSignal = True
        elif b is False and self.isRealTimeSignal:
            self.pureColorWidget.rgbaChange.disconnect()
            self.pureColorWidget.hsvRgbaChange.disconnect()
            #
            for gobj in [self.linearWidget, self.radialWidget, self.conicalWidget]:
                gobj.qssed.disconnect()
            self.isRealTimeSignal = False

    def sendStrColor(self,g_type,obj):
        if g_type == Handle_pure:
            color = self.pureColorWidget.colorbar.getColor()
            self.clickStrColor.emit("rgba({},{},{},{})".format(*color.getRgb()))
        elif obj:
            self.clickStrColor.emit(obj.getQSS())

    def switchSpread_event(self,spread):
        self.linearWidget.setSpread(spread)
        self.radialWidget.setSpread(spread)
        self.conicalWidget.setSpread(spread)

    def hide_hand_event(self,b):
        self.pureColorWidget.setHideHand(b)
        self.linearWidget.setHideHand(b)
        self.radialWidget.setHideHand(b)
        self.conicalWidget.setHideHand(b)
        self.update()



# -*- coding:utf-8 -*-
# @time:2023/2/109:28
# @author:LX
# @file:error.py
# @software:PyCharm

# -----


class SyntaxError(Exception):
    '''
        语法异常
    '''

class KeyError(Exception):
    '''
        字典的 Key 错误
    '''


# -*- coding:utf-8 -*-
# @time:2023/6/818:19
# @author:LX
# @file:test.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QVBoxLayout,
    Qt
)

from PyQtGuiLib.core.charRooms.chatRoom import ChatRoom,Transmitter,Message



class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.setWindowTitle("聊天组件")
        self.resize(800,500)
        self.vlay = QVBoxLayout(self)

        self.chat = ChatRoom()

        self.rb = Transmitter()
        self.lb = Transmitter()

        # https://www.baidu.com/
        self.vlay.addWidget(self.chat)
        self.vlay.addWidget(self.lb)
        self.vlay.addWidget(self.rb)

        self.rb.texted.connect(self.send_event)
        self.lb.texted.connect(self.receive_event)

    def send_event(self,data):
        if data:
            mes = Message(None, data)
            mes.setHeadImage(r"C:\Users\Administrator\Downloads\机器小狗-removebg-preview.png")
            self.chat.sendText(mes)

    def receive_event(self,data):
        if data:
            mes = Message("铁蛋",data)
            mes.setHeadImage(r"C:\Users\Administrator\Downloads\1-removebg-preview.png")
            self.chat.receiveText(mes)


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/4/179:03
# @author:LX
# @file:toolNewProject.py
# @software:PyCharm
import os,sys
from datetime import datetime as dt


def cuTime() -> str:
    return dt.strftime(dt.now(), "%Y-%m-%d %H:%M")

# 普通控件模板
TemplateCode = r'''# -*- coding:utf-8 -*-
# @time:{cutime}
# @author:LX
# @file:{title_className}.py
# @software:PyCharm

from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
)

{explain}

class {className}(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = {className}()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())
'''
# 绘图控件模板
PainterTemplateCode = r'''# -*- coding:utf-8 -*-
# @time:{cutime}
# @author:LX
# @file:{title_className}.py
# @software:PyCharm

from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QPoint,
    QPainter,
    QColor,
    QRect,
    QSize,
    QFont,
    QPen,
    QBrush,
    QPaintEvent,
    Qt,
    qt
)

{explain}

class {className}(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)
    
    def paintEvent(self, e:QPaintEvent) -> None:
        painter = QPainter(self)
        painter.setRenderHints(qt.Antialiasing | qt.SmoothPixmapTransform | qt.TextAntialiasing)
        
        painter.end()

if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = {className}()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())
'''

# -----------------------------------------------------------
# 根据个人情况经行配置
# 项目路径,测试项目路径
Project_Path = r"D:\code\PyQtGuiLib\PyQtGuiLib\core"
Test_Project_Path = r"D:\code\PyQtGuiLib\tests"


print("----------------------创建项目--------------------------")
project_name = input("输入项目名称:")
print("[1]创建普通控件 [2]绘图控件")
con_op = input("请选择:")
if con_op == '2':
    TemplateCode = PainterTemplateCode

print("[1]创建单个文件 [2]创建包")
createDir = input("请选择:")
if createDir == '1':
    create_file_path = os.path.join(Project_Path, project_name + ".py")
elif createDir == '2':
    file_name = input("请输入包名称:")
    create_page_dir = os.path.join(Project_Path, file_name)
    create_file_path = os.path.join(create_page_dir, file_name + ".py")
    print(create_file_path)

print("------------开始创建测试文件---------")
print("[1]创建单个测试文件 [2]创建包")
test_file = input("请选择:")
if test_file == '1':
    test_create_file_path = os.path.join(Test_Project_Path,"test_{}.py".format(project_name))
elif test_file == '2':
    test_create_page_dir = os.path.join(Test_Project_Path, "test_"+project_name)
    test_create_file_path = os.path.join(test_create_page_dir, "test_{}.py".format(project_name))

    print(test_create_page_dir)


print(create_file_path)

print(test_create_file_path)

# --------------------开始创建文件------------------------

if createDir == '1':
    if os.path.isfile(create_file_path):
        raise Exception("{} 已存在".format(create_file_path))
    else:
        with open(create_file_path,"w",encoding="utf8") as f:
            f.write(TemplateCode.format(cutime=cuTime(),title_className=project_name,className=project_name.title(),explain=""))
elif createDir == '2':
    if os.path.isdir(create_page_dir):
        raise Exception("{} 已存在".format(create_page_dir))
    else:
        os.mkdir(create_page_dir)
        open(os.path.join(create_page_dir,"__init__.py"),"w",encoding="utf8")
        with open(create_file_path,"w",encoding="utf8") as f:
            f.write(TemplateCode.format(cutime=cuTime(),title_className=project_name,className=project_name.title(),explain=""))

if test_file == '1':
    if os.path.isfile(test_create_file_path):
        raise Exception("{} 已存在".format(test_create_file_path))
    else:
        with open(test_create_file_path, "w",encoding="utf8") as f:
            f.write(TemplateCode.format(cutime=cuTime(),title_className=project_name,className="Test_"+project_name.title(), explain="# 测试文件"))
elif test_file == '2':
    if os.path.isdir(test_create_page_dir):
        raise Exception("{} 已存在".format(test_create_page_dir))
    else:
        os.mkdir(test_create_page_dir)
        open(os.path.join(test_create_page_dir,"__init__.py"),"w",encoding="utf8")
        with open(test_create_file_path, "w",encoding="utf8") as f:
            f.write(TemplateCode.format(cutime=cuTime(),title_className=project_name,className="Test_"+project_name.title(), explain="# 测试文件"))




from PyQtGuiLib.header.versions import PYQT_VERSIONS

if PYQT_VERSIONS == "PyQt5":
    from PyQt5.QtCore import *
    from PyQt5.QtCore import pyqtSignal as Signal

if PYQT_VERSIONS == "PyQt6":
    from PyQt6.QtCore import *
    from PyQt6.QtCore import pyqtSignal as Signal

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtCore import *
    from PySide2.QtCore import Property as pyqtProperty

if PYQT_VERSIONS == "PySide6":
    from PySide6.QtCore import *
    from PySide6.QtCore import Property as pyqtProperty



from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QPushButton
)
from PyQtGuiLib.core.widgets import WidgetABC

'''
    新无边框窗口
'''

class BorderlessWidget(WidgetABC):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QPushButton,
    QPoint,
    QMouseEvent,
    QWidget,
    QVBoxLayout
)
'''
    新无边框窗口主窗口,(还没有设计完成,暂时先放下 2023.1.31)
'''
from PyQtGuiLib.core.widgets import WidgetABC
from PyQtGuiLib.core.widgets.titleBar import TitleBar
from PyQtGuiLib.core.widgets.statusBar import StatusBar
# import ctypes
# ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID("myappid")

class BorderlessMainWindow(WidgetABC):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


        self.crbtn = QPushButton("创建",self)
        self.crbtn.move(40,40)
        self.crbtn.clicked.connect(self.createTitleBar)

        self.delbtn = QPushButton("删除",self)
        self.delbtn.move(100,100)
        self.delbtn.clicked.connect(self.removeTitleBar)

        # 标题风格
        self.__title_style = TitleBar.MacStyle

        self.createTitleBar()

        # self.coreWin = WidgetABC(self)
        # self.coreWin.setStyleSheet('''
        #  WidgetABC{
        #  qproperty-backgroundColor:rgba(0, 255, 127,255);
        #  }
        #  ''')
        # self.setCentralWidget(self.coreWin)

        # self.status = StatusBar(self)
        # self.status.setStatusPos(StatusBar.PosBottom)
        # self.status.addText("我是标签")

    def setTitleBtnStyle(self,style="mac"):
        if style.lower() == "win":
            self.__title_style = TitleBar.WinStyle
        else:
            self.__title_style = TitleBar.MacStyle

    # 返回标题风格
    def titleStyle(self) -> str:
        return self.__title_style

    # 创建标题栏
    def createTitleBar(self):
        if not hasattr(self,"titlebar"):
            h,s,v,a = self.get_backgroundColor().getHsv()
            v = 0 if v - 30 < 0 else v-30

            self.titlebar = TitleBar(self)
            self.titlebar.setBtnStyle(self.titleStyle())
            self.titlebar.setStyleSheet('''
            TitleBar{
            qproperty-fontSize:14;
            qproperty-borderWidth:0;
            qproperty-borderColor:hsv(%d, %d, %d,%d);
            qproperty-backgroundColor: hsv(%d, %d, %d,%d);
            }
            '''%(h,s,v,a,h,s,v,a))
            self.titlebar.show()

    def paintEvent(self, event) -> None:
        super().paintEvent(event)
        if hasattr(self, "titlebar"):
            h, s, v, a = self.get_backgroundColor().getHsv()
            v = 0 if v - 30 < 0 else v - 30
            self.titlebar.setStyleSheet('''
                        TitleBar{
                        qproperty-fontSize:14;
                        qproperty-borderWidth:0;
                        qproperty-borderColor:hsv(%d, %d, %d,%d);
                        qproperty-backgroundColor: hsv(%d, %d, %d,%d);
                        }
                        ''' % (h, s, v, a, h, s, v, a))


    def setCentralWidget(self,widget:QWidget):
        if hasattr(self, "titlebar"):
            widget.resize(self.width()-4,self.height()-self.titlebar.height())
            widget.move(2,self.titlebar.height()-2)
        else:
            widget.resize(self.size())

    # 返回标题对象
    def titleObj(self)->TitleBar:
        if hasattr(self, "titlebar"):
            return self.titlebar
        else:
            return None

    # 移除标题栏
    def removeTitleBar(self):
        if hasattr(self,"titlebar"):
            self.titlebar.deleteLater()
            del self.titlebar



if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = BorderlessMainWindow()
    # win.setEnableGColor(True)
    win.setStyleSheet('''
qproperty-radius:7;
qproperty-backgroundColor:rgba(255, 170, 127,255);
    ''')
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/4/2817:23
# @author:LX
# @file:table.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QTableWidget,
    QTableWidgetItem,
    qt,
    Qt,
    QPushButton
)

from typing import List,Optional


class HeaderItem(QPushButton):
    def __init__(self,text:str):
        super().__init__()
        self.setText(text)

        self.setStyleSheet('''
        border:none;
        ''')


class Table(QTableWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

        self.horizontalHeader().setVisible(False)
        self.verticalHeader().setVisible(False)

        self.setGrid(5,5)
        self.setHeaderLabels(["A","B","C","D"],True)

    def setHeaderLabels(self,labels:List[str],center=False):
        for i,label in enumerate(labels):
            item = HeaderItem(label)
            self.setCellWidget(0,i+1,item)

    def setGrid(self,row:int,col:int):
        self.setRowCount(row)
        self.setColumnCount(col)

    def gridSize(self)->tuple:
        return self.rowCount(),self.columnCount()



if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Table()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQt5.QtWidgets import QApplication, QWidget, QListWidget, QPushButton, QVBoxLayout
from PyQt5.QtCore import Qt, QMimeData
from PyQt5.QtGui import QDrag


class SourceListWidget(QListWidget):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.setSelectionMode(self.SingleSelection)



    def startDrag(self, supportedActions):
        item = self.currentItem()
        if item is not None:
            drag = QDrag(self)
            mimeData = QMimeData()
            mimeData.setText(item.text())
            drag.setMimeData(mimeData)
            drag.exec_(Qt.CopyAction)


class TargetWidget(QWidget):
    def __init__(self):
        super().__init__()
        self.setAcceptDrops(True)
        self.setStyleSheet('''border:1px solid blue;''')

        self.setMinimumHeight(50)
        self.layout = QVBoxLayout(self)
        self.layout.setAlignment(Qt.AlignTop)

    def dragEnterEvent(self, event):
        if event.mimeData().hasText():
            event.accept()
        else:
            event.ignore()

    def dropEvent(self, event):
        if event.mimeData().hasText():
            pos = event.pos()
            text = event.mimeData().text()
            button = QPushButton(text, self)
            button.move(pos)
            button.show()
            event.accept()
        else:
            event.ignore()


class MainWindow(QWidget):
    def __init__(self):
        super().__init__()
        self.setWindowTitle('Drag and Drop')
        self.setGeometry(200, 200, 400, 300)

        self.sourceListWidget = SourceListWidget(self)
        self.targetWidget = TargetWidget()

        layout = QVBoxLayout(self)
        layout.addWidget(self.sourceListWidget)
        layout.addWidget(self.targetWidget)


if __name__ == '__main__':
    import sys
    app = QApplication(sys.argv)
    window = MainWindow()
    window.show()
    sys.exit(app.exec_())



# -*- coding:utf-8 -*-
# @time:2023/4/2014:53
# @author:LX
# @file:particle.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QColor,
    QSize,
    QPoint,
    QTimer,
    QPointF,
    QPainter,
    QBrush,
    QOpenGLWidget,
    QMouseEvent,
    QPropertyAnimation,
    QObject,
    QEasingCurve
)

import random

from functools import partial

def rcolor()->QColor:
    return QColor(random.randint(0,255),random.randint(0,255),random.randint(0,255))


# 粒子的位置和速度
class ParticleAttr:
    def __init__(self, pos:QPoint):
        self.pos = pos
        self.speed = QPointF((0.5 - random.random()) * 2, (0.5 - random.random()) * 2)

        self._flag = True
        self._num = 100
        self._cnum = 0
        self.update(pos)

    def update(self,pos):
        self.pos = pos
        # self.pos += QPointF(x,y)+self.mpos


class ParticleSystem:
    def __init__(self, num_particles,parent):
        self.particles = [ParticleAttr(QPointF(random.random() * 400+100, random.random() * 200+100)) for _ in range(num_particles)]
        self.parent = parent

        self._bru = QBrush(rcolor())
        self.mpos = QPointF(10,10)

    # 更新粒子的位置
    def update(self):
        es = [QEasingCurve.SineCurve,QEasingCurve.InCurve,QEasingCurve.OutCurve,
              QEasingCurve.CosineCurve,QEasingCurve.Linear]


        for particle in self.particles:
            ani = QPropertyAnimation(QObject(),b"pos",self.parent)
            ani.setEasingCurve(random.choice(es))
            # ani.setEasingCurve(es[-1])
            ani.setStartValue(QPoint(int(particle.pos.x()),int(particle.pos.y())))
            ani.setEndValue(self.mpos-QPoint(random.randint(20,60),
                            random.randint(20,60))
                            )
            ani.valueChanged.connect(partial(self.ani_event,particle))
            ani.start()


    def ani_event(self,particle,pos):
        particle.update(pos)
        self.parent.update()


    def setMouPos(self,pos:QPointF):
        self.mpos = pos

    # 绘制粒子
    def draw(self, painter):
        for particle in self.particles:
            painter.setBrush(self._bru)
            painter.drawEllipse(particle.pos, 3, 3)


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

        self.setGeometry(100, 100, 400, 400)

        self.particle_system = ParticleSystem(100)

        self.timer = QTimer(self)
        self.timer.timeout.connect(self.update_particles)
        self.timer.start(30)

        self.setMouseTracking(True)

        self.mouPos = QPointF(10,10)

    def mouseMoveEvent(self,e:QMouseEvent) -> None:
        self.particle_system.updateMouPos(QPointF(e.pos()))
        super().mouseMoveEvent(e)

    def update_particles(self):
        self.particle_system.update()
        self.update()

    def paintEvent(self, event):
        painter = QPainter(self)
        painter.setRenderHint(QPainter.Antialiasing)
        self.particle_system.draw(painter)


class Test2(QWidget):
    def __init__(self):
        super().__init__()

        self.setMouseTracking(True)

        self.part = ParticleSystem(500,self)

    def mouseMoveEvent(self, e:QMouseEvent):
        # print(e)
        self.part.setMouPos(e.pos())
        self.part.update()
        super().mouseMoveEvent(e)

    def paintEvent(self, event):
        painter = QPainter(self)
        painter.setRenderHint(QPainter.Antialiasing)
        self.part.draw(painter)

if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test2()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.core.bubbleWidget import BubbleWidget
from PyQtGuiLib.core.pullOver import PullOver
from PyQtGuiLib.core.slideShow import SlideShow
from PyQtGuiLib.core.flowLayout import FlowLayout
from PyQtGuiLib.core.listWidget import ListWidget
from PyQtGuiLib.core.rollWidget import RollWidget
from PyQtGuiLib.core.palettes.paletteFrame import PaletteFrame
from PyQtGuiLib.core.palettes.paletteTools.palettetools import PaletteTools
from PyQtGuiLib.core.notice.notice import Notice,Notices
from PyQtGuiLib.core.slider.slider import Slider
from PyQtGuiLib.core.toolList import ToolListWidget,ToolListItem
from PyQtGuiLib.core.drawers.drawer import DrawerItem,Drawer
from PyQtGuiLib.core.comboBox.comboCheckBox.comboCheckBox import ComboCheckBox
from PyQtGuiLib.core.pager.pageCuttingButtonGroup import PageCuttingButtonGroup


# -*- coding:utf-8 -*-
# @time:2022/12/1711:39
# @author:LX
# @file:borderlessWidget.py
# @software:PyCharm

from abandonCase.widgets.borderlessWidgetABC import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    Public,
    QWidget,
    QMouseEvent,
    QPaintEvent,
)


# 无边框的QWidget
class BorderlessWidget(QWidget,Public):
    def __init__(self,*args,**kwargs):
        self.child_win = True if args else False
        super().__init__(parent_=self,*args,**kwargs)
        self.resize(800, 500)


    def mousePressEvent(self, e:QMouseEvent) -> None:
        if not self.child_win:
            self.borderless.pressEvent(self,e)
        super().mousePressEvent(e)

    def mouseReleaseEvent(self, e:QMouseEvent) -> None:
        if not self.child_win:
            self.borderless.releaseEvent()
        super().mouseReleaseEvent(e)

    def mouseMoveEvent(self, e:QMouseEvent) -> None:
        if not self.child_win:
            self.borderless.moveEvent(self,e)
        super().mouseMoveEvent(e)

    def paintEvent(self, e: QPaintEvent) -> None:
        self.borderless.pEvent(self,e)
        super().paintEvent(e)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = BorderlessWidget()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/2/914:20
# @author:LX
# @file:__init__.py.py
# @software:PyCharm
import sys
from PyQt5.QtWidgets import QApplication, QMainWindow, QLabel, QLineEdit, QPushButton, QVBoxLayout, QWidget
from PyQt5.QtMultimedia import QCamera, QCameraImageCapture
# QCameraViewfinder

class LoginWindow(QMainWindow):
    def __init__(self):
        super().__init__()

        # 创建窗口
        self.setWindowTitle('QQ Login')
        self.setGeometry(100, 100, 300, 200)

        # 创建界面
        widget = QWidget()
        self.setCentralWidget(widget)

        # 添加元素
        label = QLabel('Username:')
        self.username = QLineEdit()
        button = QPushButton('Scan to Login')
        button.clicked.connect(self.scan_login)

        # 布局管理
        layout = QVBoxLayout()
        layout.addWidget(label)

        layout.addWidget(self.username)
        layout.addWidget(button)
        widget.setLayout(layout)

    def scan_login(self):
        camera = QCamera()
        # viewfinder = QCameraViewfinder()
        image_capture = QCameraImageCapture(camera)

        # camera.setViewfinder(viewfinder)
        camera.start()

        # 读取二维码信息并完成扫描登录
        # 此处需要根据具体实现方法进行修改
        qr_code = image_capture.capture()
        camera.stop()

        # 处理登录结果
        # 此处需要根据具体实现方法进行修改
        if qr_code:
            self.username.setText('Login Success')
        else:
            self.username.setText('Login Failed')

if __name__ == '__main__':
    app = QApplication(sys.argv)
    login_window = LoginWindow()
    login_window.show()
    sys.exit(app.exec_())




from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    qt,
    Qt,
    QPoint,
    QPainter,
    QColor,
    QRect,
    QBrush,
    QPen,
    QPaintEvent,
    QGraphicsDropShadowEffect,
    QVBoxLayout,
    QSize,
    QMainWindow,
    QMenuBar,
    QAction,
    QMenu,
    QIcon,
    QPixmap,
    qt,
)
'''
https://icons8.com/
https://www.flaticon.com/
https://www.iconfinder.com/
'''


from PyQt5 import QtCore

class Test(QWidget):

    def __init__(self,*args,**kwargs):
        super(Test, self).__init__(*args,**kwargs)

        self.spring = 6

        self.vboy = QVBoxLayout(self)
        self.vboy.setContentsMargins(self.spring,self.spring,self.spring,self.spring)
        self.vboy.setSpacing(0)

        self.core = QMainWindow()
        self.core.resize(self.size())
        self.vboy.addWidget(self.core)

        # 菜单栏
        self.menubar = QMenuBar()

        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 800, 23))
        self.core.setMenuBar(self.menubar)

        self.g = QGraphicsDropShadowEffect()
        self.g.setOffset(0, 0)
        self.g.setBlurRadius(self.spring * 2)
        self.g.setColor(QColor(0, 0, 0))

        self.core.setGraphicsEffect(self.g)

        # -----------------------------------

        self.resize(QSize(800,800))
        # self.resize(100,100)

        self.setAttribute(qt.WA_TranslucentBackground,True)
        self.setWindowFlags(qt.FramelessWindowHint | qt.Widget)


        self.core.setStyleSheet('''
        background-color: rgb(255, 170, 0);
        border-radius:8px;
        ''')

        self.about = QMenu()
        icon = QIcon(r"D:\code\PyQtGuiLib\PyQtGuiLib\tests\temp_image\python1.png")
        new_size = QSize(100, 100)
        icon = icon.pixmap(new_size).scaled(new_size, QtCore.Qt.KeepAspectRatio, QtCore.Qt.SmoothTransformation)

        self.about.setIcon(QIcon(icon))
        # self.core.setWindowIcon(QIcon(r"D:\code\PyQtGuiLib\PyQtGuiLib\tests\temp_image\python1.svg"))
        self.about.setEnabled(False)
        self.about.setStyleSheet('''
        background-color: rgb(255, 170, 0);
        border-radius:10px;
        ''')
        self.test = QAction("222")
        self.about.addAction(self.test)
        self.menubar.addMenu(self.about)


    def parent(self) -> 'QObject':
        return self.core.parent()

    def size(self) -> QSize:
        # print("父类",super().size())
        return self.core.size()

    def resize(self,*args) -> None:
        if len(args) == 2:
            size = QSize(args[0],args[1])
        elif len(args) == 1 and isinstance(args[0],QSize):
            size = args[0]
        else:
            raise TypeError("size error!")

        self.core.resize(size)
        size.setWidth(size.width()+self.spring*2)
        size.setHeight(size.height()+self.spring*2)
        super().resize(size)

    def width(self) -> int:
        return self.width()

    def height(self) -> int:
        return self.height()

    def geometry(self) ->QRect:
        return self.core.geometry()


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()

    win.resize(500,500)
    print(win.size())
    print(win.geometry())
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QResizeEvent,
    QMoveEvent,
    QThread,
    Signal
)
from random import randint
from PyQtGuiLib.core import Notice,Notices


class Time(QThread):
    add = Signal()
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


    def run(self) -> None:
        n = 0
        while True:
            self.sleep(randint(1,1))
            self.add.emit()
            if n == 5:
                break
            n+=1


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

        self.th = Time()
        self.th.add.connect(self.test_add)
        self.th.start()


        self.notice = Notices(self)
        self.notice.setStyleSheet('''
        Notice{
        qproperty-radius:5;
        qproperty-backgroundColor:rgba(153, 241, 255,150);
        qproperty-fontSize:18;
        }
                ''')
        # self.notice.appendTip("hello wrold",5)
        # self.notice.appendTip("11111111",7000)
        # self.notice.appendTip("8888",8000)
        # self.notice.appendTip("我是通知栏",10000)
        # self.notice.show()

    def test_add(self):
        self.notice.appendTip("ttest{}".format(randint(1,1000)),5)


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/3/411:37
# @author:LX
# @file:eg1.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    qt,
    QPushButton,
    Qt,
    QPalette,
    QColor,
    QPaintEvent,
    QPainter,
    QBrush,
    QSize,
    QMainWindow,
    QLineEdit,
    desktopCenter,
    QPixmap,
    QLinearGradient,
    QLabel,
    QFont,
    textSize,
    QFontMetricsF,
    Qt,
    QMouseEvent,
    QPropertyAnimation,
    QRect,
    QParallelAnimationGroup,
    QResizeEvent
)
from PyQtGuiLib.core.flowLayout import FlowLayout
import time
from PyQt5.QtWidgets import QSplashScreen,QDialog,QProxyStyle,QButtonGroup
from PyQt5.QtCore import QThread,QRunnable,QThreadPool
from PyQt5.QtGui import QFontMetrics,QFocusEvent

# QSplashScreen
'''
    测试用例的标准模板,该代码用于复制
'''
from PyQtGuiLib.core.resolver import dumpStructure
from PyQtGuiLib.styles import ButtonStyle


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

        self.a = QWidget(self)
        self.b = QWidget(self)
        self.a.setObjectName("a")
        self.b.setObjectName("b")

        self.a.resize(self.width(),150)
        self.b.resize(self.width(),self.height()-150)
        self.b.move(0,150)

        self.setStyleSheet('''
#a{
border:1px solid red;
}
#b{
border:1px solid blue;
}
        ''')

        # ---
        self.af = FlowLayout(self.a)
        self.bf = FlowLayout(self.b)

        for ai in range(8):
            btn = QPushButton("test_{}".format(ai))
            btn.setFixedSize(100,50)
            btn.setStyleSheet(ButtonStyle.randomStyle())  # 使用 皮肤包
            self.af.addWidget(btn)

        for bi in range(10):
            btn = QPushButton("test_{}".format(bi))
            btn.setFixedSize(130, 60)
            btn.setStyleSheet(ButtonStyle.randomStyle())  # 使用 皮肤包
            self.bf.addWidget(btn)


        self.isf = False
        self.btn = QPushButton("开始 影像形变-布局",self)
        self.btn.resize(150,60)
        self.btn.move(300,300)
        self.btn.clicked.connect(self.test_start)
        # self.anim()

    def test_start(self):
        if self.isf is False:
            self.anim()
            self.btn.setText("恢复 影像形变-布局")
            self.isf = True
        else:
            self.anim_re()
            self.btn.setText("开始 影像形变-布局")
            self.isf = False


    def anim(self):
        pain = QParallelAnimationGroup(self)
        # pain.setDirection(3000)

        ani = QPropertyAnimation(self.a,b"geometry",self)
        ani.setDuration(1000)
        ani.setStartValue(self.a.rect())
        ani.setEndValue(QRect(self.a.x(),self.a.y(),
                              self.a.height(),self.a.width()))


        anib = QPropertyAnimation(self.b,b"geometry",self)
        anib.setDuration(1000)
        anib.setStartValue(self.b.rect())
        anib.setEndValue(QRect(150,0,
                              self.b.width()-150,self.height()))

        pain.addAnimation(ani)
        pain.addAnimation(anib)
        pain.start()


    def anim_re(self):
        pain = QParallelAnimationGroup(self)
        # pain.setDirection(3000)

        ani = QPropertyAnimation(self.a, b"geometry", self)
        ani.setDuration(1000)
        ani.setStartValue(self.a.rect())
        ani.setEndValue(QRect(self.a.x(), self.a.y(),
                              self.a.height(), self.a.width()))

        anib = QPropertyAnimation(self.b, b"geometry", self)
        anib.setDuration(1000)
        anib.setStartValue(self.b.rect())
        anib.setEndValue(QRect(0, 150,
                               self.width(), self.height()- 150))

        pain.addAnimation(ani)
        pain.addAnimation(anib)
        pain.start()


    def resizeEvent(self, e: QResizeEvent) -> None:
        self.a.resize(self.width(), 150)
        self.b.resize(self.width(), self.height() - 150)
        super().resizeEvent(e)

if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/4/269:39
# @author:LX
# @file:test_PageCuttingButtonGroup.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QStackedWidget,
    QHBoxLayout,
    QVBoxLayout,
    QLabel,
    QButtonGroup,
    QPushButton,
    QSize,
    qt
)

from PyQtGuiLib.core import PageCuttingButtonGroup

'''
    PageCuttingButtonGroup 分页组件测试
'''

class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

        pageCount = 30
        buttonCount = 10

        self.setStyleSheet("""
                    QLabel{
                    font-size:30px;
                    }
                """)
        self.stackedWidget = QStackedWidget(self)
        for i in range(pageCount):
            page = QLabel("第{}页".format(i+1), self.stackedWidget)
            page.setAlignment(qt.AlignCenter)
            self.stackedWidget.addWidget(page)

        self.pbg = PageCuttingButtonGroup(pageCount, buttonCount)

        # 直接绑定 QStackedWidget
        self.pbg.bingStackedWidget(self.stackedWidget)

        self.pbg.setCurrentPageButtonFixedSize(QSize(34, 34))
        self.pbg.setPreviousNextPageButtonFixedSize(QSize(74, 34))
        self.pbg.setSpacing(8)

        hBox = QHBoxLayout()
        hBox.addWidget(self.pbg)
        vBox = QVBoxLayout()
        vBox.addWidget(self.stackedWidget)
        vBox.addLayout(hBox)
        vBox.setStretch(0, 1)
        self.setLayout(vBox)


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/4/1112:42
# @author:LX
# @file:test_listTemplateWindow.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QLabel,
    Qt
)

from random import randint
from PyQtGuiLib.templateWindow import ListTemplateWindow

'''
    测试 实际使用 模板窗口
'''

class myWidget(ListTemplateWindow):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

        # 添加菜单
        self.addMenu({
            "text": "测试",
            "call": self.test,
        })
        self.addMenu(
            {
                "text":"隐藏第二页(测试功能)",
                "call":self.test_hide
            }
        )

        # 添加头像
        self.setHeadPicture(r"D:\code\PyQtGuiLib\tests\temp_image\python1.png")

        # 添加页面
        self.addItem("首页",self.frist_page(),r"D:\code\PyQtGuiLib\tests\temp_image\python1.png")
        self.addItem("第二页",self.two_page(),r"D:\code\PyQtGuiLib\tests\temp_image\python1.png")
        self.addItem("第三页",self.three_page(),r"D:\code\PyQtGuiLib\tests\temp_image\python1.png")

        # 头部窗口
        self.addHeadWidget(self.headWidget())

    def test_hide(self):
        if self.listWidget.item(1).isHidden():
            self.setHideItem(1,False)
        else:
            self.setHideItem(1)

    def test(self):
        print("测试回调函数")

    def frist_page(self):
        widget = QLabel("我是首页")
        widget.setAlignment(Qt.AlignCenter)
        widget.setStyleSheet('''
background-color: rgb(229, 229, 229);
font: 22pt "黑体";
        ''')
        return widget

    def three_page(self):
        widget = QLabel("第三页")
        widget.setAlignment(Qt.AlignCenter)
        widget.setStyleSheet('''
background-color: rgb(100, 100, 45);
font: 22pt "黑体";
        ''')
        return widget

    def two_page(self):
        widget = QLabel("我是第二页")
        widget.setAlignment(Qt.AlignCenter)
        widget.setStyleSheet('''
        background-color: #ffd997;
        font: 22pt "黑体";
                ''')
        return widget

    def headWidget(self):
        widget = QLabel("头部窗口")
        widget.setAlignment(Qt.AlignCenter)
        widget.setStyleSheet('''
        font: 22pt "黑体";
                ''')
        return widget

if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = myWidget()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())



from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget
)

'''
    开关按钮 测试用例
'''
from random import randint
from PyQtGuiLib.core.flowLayout import FlowLayout
from PyQtGuiLib.core.switchButtons import SwitchButton


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

        self.flow = FlowLayout(self)

        # ---
        swbtn = SwitchButton(self)
        swbtn.setDefaultState(True)
        swbtn.setFixedSize(60, 30)
        swbtn.setDefaultState(False)
        # swbtn.show()
        self.flow.addWidget(swbtn)

        swbtn1 = SwitchButton(self)
        swbtn1.setShape(SwitchButton.Shape_Square)
        swbtn1.setDefaultState(False)
        swbtn1.setFixedSize(60, 30)
        # swbtn.show()
        self.flow.addWidget(swbtn1)

if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/2/914:20
# @author:LX
# @file:eg1_QPushButton.py
# @software:PyCharm


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QPushButton,
    QLabel,
    Qt,
)
from PyQtGuiLib.styles import QssStyleAnalysis


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)


        self.setAttribute(Qt.WA_StyledBackground,True)

        self.l = QLabel("测试标签",self)
        self.btn = QPushButton("测试按钮",self)
        self.btn.setObjectName("btn")
        self.btn2 = QPushButton("测试按钮2号",self)
        self.l.move(30, 30)
        self.btn.resize(150, 80)
        self.btn.move(80, 80)
        self.btn2.resize(100,60)
        self.btn2.move(250,80)
        '''
            解析 测试1 
        '''
        # 创建一个针对整个窗口的 QSS 解析器
        self.qss = QssStyleAnalysis(self)
        # 对窗口上所有按钮,标签设置样式
        self.qss.setQSS('''
        QPushButton{
        color: rgb(0, 255, 127);
        background-color:rgb(0, 170, 0);
        }
        QLabel{
        color: rgb(42, 55, 127);
        background-color:rgb(255, 170, 0);
        }
        ''')
        print(self.qss.toStr()) # 返回样式的原始的类型
        print(self.qss.toDict()) # 返回样式的字典类型
        print("----------------------------------------------------")
        print(self.qss.selector("QPushButton").header()) # 获取按钮的选择器
        print(self.qss.selector("QPushButton").headerSubdivision()) # 在有多个选择器的这个才能看到效果
        print(self.qss.selector("QPushButton").body()) # 获取该选择器的原始样式
        print(self.qss.selector("QPushButton").bodySubdivision()) # 将原始样式已列表的形式返回
        print(self.qss.selector("QLabel").bodyToDict()) # 将原始样式已字典的形式返回(不带选择器)
        print(self.qss.selector("QLabel").toDict()) # 将原始样式已字典的形式返回(带选择器)


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QPushButton,
    QVBoxLayout
)

'''
   调色板 测试用例
'''

from PyQtGuiLib.core import PaletteFrame

class Test_ColorPalette(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

#         self.setStyleSheet('''
# background-color: rgb(25, 25, 25);
#         ''')
        self.vboy = QVBoxLayout(self)

        self.pcolor = PaletteFrame(self,shape=PaletteFrame.Rect)
        self.pcolor.resize(500,300)
        self.pcolor.move(10,10)
        self.pcolor.rgbaChange.connect(self.test)
        # self.pcolor.nameChange.connect(self.test_name)
        # self.pcolor.clickColor.connect(self.test_click)

        # 测试按钮
        self.btn = QPushButton("test",self)
        self.btn.move(50,400)
        self.btn.resize(80,80)

        self.vboy.addWidget(self.pcolor)
        self.vboy.addWidget(self.btn)


    def test(self,rgba:tuple):
        print("-->",rgba)
        self.btn.setStyleSheet('''
background-color: rgba(%s, %s, %s,%s);
        '''%(rgba))

    def test_name(self,name):
        print(name)
        self.btn.setStyleSheet('''
        background-color: %s;
                ''' % (name))

    def test_click(self,rgba:tuple):
        print("-->",rgba)
        self.btn.setStyleSheet('''
background-color: rgba(%s, %s, %s,%s);
        '''%(rgba))

if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test_ColorPalette()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/2/1817:13
# @author:LX
# @file:styleLinkerUi.py
# @software:PyCharm
from PyQtGuiLib.header import (
    QWidget,
    QTabWidget,
    qt,
    QTreeWidget,
    QHBoxLayout,
    QSplitter,
    QTextBrowser
)


class StyleLinkerUI(QWidget):
    def __init__(self):
        super().__init__()
        self.resize(800,600)

        self.setWindowTitle("动态样式链接器")

        self.Init()


    def Init(self):
        self.__hboy = QHBoxLayout(self)
        self.__hboy.setContentsMargins(0,0,0,0)
        self.__spliter = QSplitter()
        self.__hboy.addWidget(self.__spliter)

        self.__tree = QTreeWidget()
        self.__tree.header().setVisible(False)
        self.__tab = QTabWidget()
        self.defaultPage = QTextBrowser()
        self.__tab.addTab(self.defaultPage,"样式代码")

        self.__spliter.addWidget(self.__tree)
        self.__spliter.addWidget(self.__tab)
        self.__spliter.setStretchFactor(1,8)

    def browser(self)->QTextBrowser:
        return self.defaultPage

    def tree(self)->QTreeWidget:
        return self.__tree

    def tab(self)->QTabWidget:
        return self.__tab


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = StyleLinkerUI()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.header import (
    QColor,
    qt,
    Qt,
    QPoint,
    QRect,
    pyqtProperty,
)

import re
import json
'''
    公共自定义样式
'''

def strRGBA_to_RGBA(rgba_str:str)->list:
    return [int(v) for v in re.findall(r"\d+",rgba_str)]


class CustomStyle:
    def __init__(self,*args,**kwargs):
        self._radius = 0
        self._backgroundColor = QColor(234, 234, 234)
        self._color = QColor(0,0,0)
        self._fontSize = 15
        self._fontStyle = "Heiti SC"
        self._font = "15 'Heiti SC'"
        self._borderWidth = 1
        self._borderStyle = "solid"
        self._borderColor = QColor(0,0,0)
        self._border = "1 solid QColor(0,0,0)"

        # 线性渐变
        self._linearDirection = "LR"
        self._linearColor = "rgba(153, 153, 230, 60) rgba(98, 98, 147, 255)"
        self._linear ="LR rgba(153, 153, 230, 60) rgba(98, 98, 147, 255)"
        #

        # ----
        # 内边距
        self._margin = 2

    def __set_radius(self,r:int):
        self._radius = r

    def get_radius(self)->int:
        return self._radius

    def __set_backgroundColor(self,bgcolor:QColor):
        self._backgroundColor = QColor(*bgcolor.getRgb())

    def get_backgroundColor(self) -> QColor:
        return self._backgroundColor

    def __set_color(self,color:QColor):
        self._color = color

    def get_color(self)->QColor:
        return self._color

    def __set_fontSize(self,size:int):
        self._fontSize = size

    def get_fontSize(self)->int:
        return self._fontSize

    def __set_fontStyle(self,style:str):
        self._fontStyle = style

    def get_fontStyle(self) -> str:
        return self._fontStyle

    def __set_font(self,fontstr:str):
        size,style = fontstr.split(" ")
        self.__set_fontSize(int(size))
        self.__set_fontStyle(style)

    def get_font(self)->str:
        return "{},{}".format(self.get_fontSize(),self.get_fontStyle())

    def __set_borderWidth(self,width:int):
        self._borderWidth = width

    def get_borderWidth(self)->int:
        return self._borderWidth

    def __set_borderStyle(self,style:str):
        self._borderStyle = style

    def get_borderStyle(self) -> Qt.PenStyle:
        style_dict = {
            "dash": qt.DashLine,
            "dot": qt.DotLine,
            "dashdot": qt.DashDotLine,
            "solid": qt.SolidLine
        }
        if style_dict.get(self._borderStyle.lower(), None):
           return style_dict[self._borderStyle.lower()]
        else:
            return qt.SolidLine

    def __set_borderColor(self,color:QColor):
        if isinstance(color,str):
            self._borderColor = QColor(*strRGBA_to_RGBA(color))
        else:
            self._borderColor = color

    def get_borderColor(self)->QColor:
        return self._borderColor

    def __set_border(self,borderstr:str):
        width,style,color = borderstr.split(" ",2)
        self.__set_borderWidth(int(width))
        self.__set_borderStyle(style)
        self.__set_borderColor(color)

    def get_border(self) -> str:
        return "{},{},{}".format(self.get_borderWidth(),self.get_borderStyle(),self.get_borderColor())

    def __set_margin(self,v:int):
        self._margin = v

    def get_margin(self) -> int:
        return self._margin

    # 渐变
    def __set_linearDirection(self,direction:QRect):
        '''
            qproperty-linearDirection:LR
            qproperty-linearDirection:UD
            qproperty-linearDirection:"[0,0,100,100]"或者"[0,0,w,h]"
        :param direction:
        :return:
        '''
        self._linearDirection = direction

    def get_linearDirection(self) ->str:
        linearDirection_dict = {
            "LR":[0, self.height(),self.width(), self.height()],
            "RL":[self.width(), self.height(),0, self.height()],
            "UD":[self.width(), 0,self.width(), self.height()],
            "DU":[self.width(), self.height(),self.width(), 0],
            "LRANG":[0,0,self.height(),self.width()],
            "RLANG":[self.height(),self.width(),0,0],
            "UDANG":[self.width(),0,0,self.height()],
            "DUANG":[0,self.height(),self.width(),0]
        }
        try:
            if linearDirection_dict.get(self._linearDirection.upper(),None):
                return json.dumps(linearDirection_dict[self._linearDirection.upper()])
            else:
                return self._linearDirection
        except Exception as e:
            print(e)
            return json.dumps(linearDirection_dict["LR"])

    def __set_linearColor(self,color_str:str):
        self._linearColor = color_str

    def get_linearColor(self) -> str:
        return self._linearColor

    def __set_linear(self,linear_gradient:str):
        self._linear = linear_gradient
        if "[" in linear_gradient and "]" in linear_gradient:
            direction,colors = linear_gradient.split("]")
            direction+="]"
        else:
            direction, colors = linear_gradient.split(" ",1)
        self.__set_linearDirection(direction)
        self.__set_linearColor(colors)

    def get_linear(self)->str:
        return self._linear

    radius = pyqtProperty(int,fset=__set_radius,fget=get_radius)
    color = pyqtProperty(QColor, fset=__set_color, fget=get_color)
    backgroundColor = pyqtProperty(QColor, fset=__set_backgroundColor, fget=get_backgroundColor)
    fontSize = pyqtProperty(int, fset=__set_fontSize, fget=get_fontSize)
    fontStyle = pyqtProperty(str,fset=__set_fontStyle,fget=get_fontStyle)
    font = pyqtProperty(str,fset=__set_font,fget=get_font)
    borderWidth = pyqtProperty(int,fset=__set_borderWidth,fget=get_borderWidth)
    borderStyle = pyqtProperty(str,fset=__set_borderStyle,fget=get_borderStyle)
    borderColor = pyqtProperty(QColor, fset=__set_borderColor, fget=get_borderColor)
    border = pyqtProperty(str, fset=__set_border, fget=get_border)
    margin = pyqtProperty(int,fset=__set_margin,fget=get_margin)
    # 线性渐变
    linearDirection = pyqtProperty(str,fset=__set_linearDirection,fget=get_linearDirection)
    linearColor = pyqtProperty(str,fset=__set_linearColor,fget=get_linearColor)
    linear = pyqtProperty(str,fset=__set_linear,fget=get_linear)



# -*- coding:utf-8 -*-
# @time:2022/12/2710:59
# @author:LX
# @file:test_gradientBar.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QPushButton,
    qt,
    QPropertyAnimation,
    QColor,
    QGraphicsBlurEffect,
    QLabel
)

from PyQtGuiLib.core.widgets import BorderlessWidget
'''
    无边框QWidget窗口 测试
'''

class TestNoBorder(BorderlessWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(500,500)

        # self.setEnableGColor(True)
        self.setStyleSheet('''
        WidgetABC{
        qproperty-radius:10;
        qproperty-backgroundColor: rgba(240, 240, 240,255);
        /*qproperty-linearDirection:"LR";
        qproperty-linearColor:"rgba(142, 144, 69, 255) rgba(176, 184, 130, 255) rgba(130, 184, 130, 255)";
        qproperty-linear:"LR rgba(142, 144, 69, 255) rgba(176, 184, 130, 255) rgba(130, 184, 130, 255)";*/
        qproperty-border:"1 solid rgba(0, 0, 0, 255)";
        /*qproperty-ani:xx; 窗口动画*/
        }
        #     ''')



        self.flag = False
        # self.btn = QPushButton("固定", self)
        # self.btn.resize(self.size())
        # self.btn.move(100, 100)
        # self.btn.clicked.connect(self.test)


    def test(self):
        if self.flag is False:
            self.btn.setText("解放")
            self.windowHandle().setFlags(self.windowFlags() | qt.WindowStaysOnTopHint)
            self.flag= True

            self.ani = QPropertyAnimation(self, b"backgroundColor")
            self.ani.setDuration(4000)
            self.ani.setLoopCount(-1)
            self.ani.setStartValue(self.get_backgroundColor())
            self.ani.setKeyValueAt(0.4, QColor(200, 100, 45, 230))
            self.ani.setKeyValueAt(0.6, QColor(200, 50, 45, 200))
            self.ani.setKeyValueAt(0.8, QColor(200, 0, 45, 150))
            self.ani.setEndValue(self.get_backgroundColor())
            #
            self.ani.start()
        else:
            self.btn.setText("固定")
            self.windowHandle().setFlags(self.windowFlags() | qt.Widget)
            self.flag = False
        self.show()
        self.update()

if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = TestNoBorder()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.core.widgets.WidgetABC import WidgetABC
from PyQtGuiLib.core.widgets.borderlessWidget import BorderlessWidget
from PyQtGuiLib.core.widgets.borderlessMainWindow import BorderlessMainWindow
from PyQtGuiLib.core.widgets.titleBar import TitleBar


# -*- coding:utf-8 -*-
# @time:2023/3/3117:04
# @author:LX
# @file:loadLogTh.py
# @software:PyCharm
import os
import time
from PyQtGuiLib.header import (
    QThread,
    Signal
)

# 本地日志管理
class LoadLocalLog(QThread):
    loaded = Signal(str)
    finish = Signal()

    def __init__(self, path=".",filename="test.txt",encoding="utf8",limit=1000):
        super().__init__()
        self.__local_log = {
            "path": path,
            "filename": filename
        }
        self.__encoding = encoding
        self.__limit = limit

    def setLimit(self,n:int):
        self.__limit = n

    def limit(self)->int:
        return self.__limit

    def encoding(self) -> str:
        return self.__local_log

    def setLocalFileInfo(self, path, filename):
        self.__local_log["path"] = path
        self.__local_log["filename"] = filename

    def localFileInfo(self) -> dict:
        return self.__local_log

    def path(self) -> str:
        return self.__local_log["path"]

    def fileName(self) -> str:
        return self.__local_log["filename"]

    def run(self):
        old = time.time()
        # print("开始:",old)
        path = os.path.join(self.path(),self.fileName())
        with open(path,"r") as f:
            n = 0
            size = 0
            limit = self.limit()
            while n<limit or limit == -1:
                data = f.readline()
                if data:
                    size += len(data)
                    self.loaded.emit(data)
                    # self.msleep(1)
                else:
                    break
                n += 1
        print("数据量:{} 字节大小:{}".format(n,size))
        new = time.time()
        print("耗时:",new-old)
        self.finish.emit()



# -*- coding:utf-8 -*-
# @time:2023/3/2717:33
# @author:LX
# @file:logBrowser.py
# @software:PyCharm
import os
import time
from datetime import datetime as dt
from PyQtGuiLib.header import (
    QApplication,
    sys,
    PYQT_VERSIONS,
    QWidget,
    QTextBrowser,
    QThread,
    Signal,
    QObject,
    QScrollBar,
    QListWidget,
    QMutex
)
from PyQtGuiLib.core.logBrowser.logSizeTh import LogSizeTh
from PyQtGuiLib.core.logBrowser.loadLogTh import LoadLocalLog


TimeFormat = str


# 日志缓存
class LogCache(QObject):
    finish = Signal()

    def __init__(self):
        super().__init__()
        self.__logs = {
            "logs":[],
            "max":2,
            "value":0
        }

    def isEmpty(self)->bool:
        return False if self.__logs["logs"] else True

    def allLogs(self)->list:
        return self.__logs["logs"]

    def setMaxValue(self,v:int):
        self.__logs["max"] = v

    def pushLog(self,log:str):
        self.__logs["logs"].append(log)
        self.addValue()
        '''
            当缓存的日志到达最大值,会触发一个信号,通知需要同步到本地文本/服务器,
        '''
        if self.isMax():
            self.finish.emit()

    def isMax(self) -> bool:
        return True if self.value() == self.maxValue() else False

    def addValue(self):
        self.__logs["value"]+=1

    def resetLog(self):
        self.__logs["logs"].clear()
        self.__logs["value"] = 0

    def maxValue(self)->int:
        return self.__logs["max"]

    def value(self)->int:
        return self.__logs["value"]



# 日志控件
class LogBrowser(QTextBrowser):
    Debug = "Debug"
    Info = "Info"
    Warning = "Warning"
    Error = "Error"
    Critical = "Critical"

    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

        self.__timeFormat = "%Y-%m-%d %H:%M:%S"
        self._start_slider_value = 0
        self._next_slider_value = 0

        '''
            将日志暂时存储在内存中,避免过渡读取磁盘
        '''
        self.__logs = LogCache()
        self.__mutex = QMutex()

        # 本地日志路径
        self.__localLogPath = "."
        self.myEvents()

    def setMemoryLogMax(self,v:int):
        self.__logs.setMaxValue(v)

    def setLocalLogPath(self,path):
        self.__localLogPath = path

    def localLogPath(self) -> str:
        return self.__localLogPath

    # 在第一次加载日志后,初始化滚动条
    def init_slider_event(self):
        self.verticalScrollBar().setValue(0)
        self._start_slider_value = self.verticalScrollBar().value()
        self._next_slider_value = self.verticalScrollBar().value()

    def sliderValue(self) -> int:
        return self.verticalScrollBar().value()

    def wheelEvent(self, *args, **kwargs):
        self._next_slider_value = self.sliderValue()
        print(self._start_slider_value,self._next_slider_value)
        if self._next_slider_value > self._start_slider_value:
            print("向下")
        elif self._next_slider_value < self._start_slider_value:
            print("向上")

        self._start_slider_value = self._next_slider_value
        super().wheelEvent(*args,**kwargs)

    def info(self,i):
        print(i)

    def test(self,info):
        self.append(info,LogBrowser.Debug)

    def setTimeFormat(self,format:TimeFormat):
        self.__timeFormat = format

    def timeFormat(self) -> TimeFormat:
        return self.__timeFormat

    def append(self, p_str,mode="Info"):
        '''
            每次写入的输入会存入内存,当然数据到达一定的量的时候,
            才会写入本地,避免过渡读取磁盘

        :param p_str:
        :param mode:
        :return:
        '''
        for_time = dt.strftime(dt.now(),self.timeFormat())
        log = "{mode} [{time}] > {info}".format(mode=mode,
                                            time=for_time,
                                            info=p_str.replace("\n",""))
        self.__logs.pushLog(log+"\n")
        super().append(log)

    # 将日志一次性存入本地
    def saveLocalLog(self):
        if not self.__logs.isEmpty():
            self.__mutex.lock()  # 保证多线程的安全
            with open(self.localLogPath(),"a+") as f:
                f.write("".join(self.__logs.allLogs()))
            self.__logs.resetLog() # 这里需要调用一下重置
            self.__mutex.unlock()

    def closeEvent(self, a) -> None:
        self.saveLocalLog()
        super().closeEvent(a)

    def myEvents(self):
        self.__logs.finish.connect(lambda :self.saveLocalLog())

if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = LogBrowser()
    win.show()
    win.setLocalLogPath(r"D:\code\PyQtGuiLib\PyQtGuiLib\core\logBrowser\test.log")


    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())




# -*- coding:utf-8 -*-
# @time:2023/4/2516:11
# @author:LX
# @file:test_ComboCheckBox.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
)

from PyQtGuiLib.core import ComboCheckBox


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

        self.combox = ComboCheckBox(
            self,
            obj_name='extendCCBox',
            spacing=0,
            width=500,
            items=[]
        )
        lst = ['齐辉0', '齐辉1', '齐辉2', '齐辉3', '悯农', '骆宾王', '凡士林', '孙悟空', '李逵', '迈阿密', '黑龙江', '石油',
               '前十', '酱油', '狐狸', '寒冰', '开户行', '天行健君子以自强不息', '业精于勤荒于嬉行成于思毁于随']

        self.combox.add_items(lst)
        self.combox.only_text('齐辉0')

        self.combox.linSignal[object].connect(lambda x: print(x))
        print(self.combox.currentText())


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/5/269:53
# @author:LX
# @file:test_PaletteTools.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QColor,
    QVBoxLayout,
    QLabel,
    QPushButton
)

from PyQtGuiLib.core import PaletteTools


'''

'''

class Test(QWidget):
    def __init__(self):
        super().__init__()

        self.resize(500, 300)

        self.vlay = QVBoxLayout(self)

        self.view = QLabel()
        self.view.setMinimumHeight(100)
        self.view.move(10, 10)

        self.btn = QPushButton()
        self.btn.setText("打开调色板")
        self.btn.setFixedHeight(50)

        self.vlay.addWidget(self.view)
        self.vlay.addWidget(self.btn)

        # 作为子窗口嵌入
        # self.ptools = PaletteTools()
        # self.vlay.addWidget(self.ptools)
        # self.ptools.setEnableRealTimeSignal(True)
        # self.ptools.clickSolidColor.connect(lambda c: self.view.setStyleSheet("background-color:" + c))
        # self.ptools.clickStrColor.connect(lambda c: self.view.setStyleSheet("background-color:" + c))

        self.btn.clicked.connect(self.updateColor)

    def updateColor(self):
        if not hasattr(self, "ptools"):
            self.ptools = PaletteTools()
            # 激活颜色实时跟踪
            self.ptools.setEnableRealTimeSignal(True)
            self.ptools.clickSolidColor.connect(lambda c: self.view.setStyleSheet("background-color:" + c))
            self.ptools.clickStrColor.connect(lambda c: self.view.setStyleSheet("background-color:" + c))
        self.ptools.show()


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())



from PyQtGuiLib.header import (
    Qt,
    QSize,
    QColor,
    QPainter,
    QPen,
    QPainterPath,
    QFont,
    QFontMetrics,
    QWidget,
    Signal,
    QRectF,
    QPointF,
    pyqtProperty,
    QTimer
)
import math

class CircularProgressBar(QWidget):
    """
    环形进度条，中间显示百分比进度
    """
    valueChanged = Signal(int)

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.setAttribute(Qt.WidgetAttribute.WA_StyledBackground, True)
        self._penWidth = 5  # 圆环的宽度
        self._startAngle = 450
        self._endAngle = 90
        self._value = 0  # 当前进度
        self._minimum = 0  # 最小值
        self._maximum = 100  # 最大值
        self._bgColor = QColor(255, 255, 255)  # 背景色
        self._progressColor = QColor(0, 255, 0)  # 进度条颜色
        self._textColor = QColor(0, 0, 0)  # 文字颜色
        self._font = self.font()  # 字体
        self._formatStr = "{:.0f}%"  # 显示格式
        self.__personalInformation = {
            "author":"PyQt5学习爱好群-讨厌自己",
            "contribution time":"2023.4.13"
        }

        # 动画相关
        self._timer = QTimer(self)
        self._step = 0
        self._numSteps = 100
        self._interval = 30

        self._timer.timeout.connect(self._animate)
        self._timer.setInterval(self._interval)

    def author(self) -> str:
        return self.__personalInformation

    def setChunkWidth(self, w: int):
        """设置圆环的宽度"""
        self._penWidth = w
        self.update()

    @pyqtProperty(int)
    def value(self):
        return self._value

    def setValue(self, val):
        if val != self._value:
            val = min(self._maximum, max(self._minimum, val))
            self._value = val
            self.valueChanged.emit(self._value)
            self.update()

    def __setValue(self, val):
        val = min(self._maximum, max(self._minimum, val))
        self.valueChanged.emit(self._value) if val != self._value else None
        self._value = val
        self.update()

    def animate(self, targetValue, duration):
        self._timer.stop()
        self._step = 0
        self._numSteps = duration / self._interval
        self._targetValue = targetValue
        self._stepSize = (self._targetValue - self._value) / self._numSteps
        self._timer.start()

    def _animate(self):
        self._step += 1
        if self._step > self._numSteps:
            self._timer.stop()
            self.setValue(self._targetValue)
        else:
            self.setValue(self._value + self._stepSize)

    def minimum(self):
        return self._minimum

    def setMinimum(self, minVal):
        if minVal != self._minimum:
            self._minimum = minVal
            self.__setValue(self._value)

    def maximum(self):
        return self._maximum

    def setMaximum(self, maxVal):
        if maxVal != self._maximum:
            self._maximum = maxVal
            self.__setValue(self._value)

    def setRange(self, minVal, maxVal):
        if minVal != self._minimum or maxVal != self._maximum:
            self._minimum = minVal
            self._maximum = maxVal
            self.__setValue(self._value)

    def setFormat(self, fmt):
        self._formatStr = fmt

    def setFont(self, font):
        self._font = font

    def setBgColor(self, color):
        self._bgColor = color

    def setProgressColor(self, color):
        self._progressColor = color
        self.update()

    def setTextColor(self, color):
        self._textColor = color

    def paintEvent(self, event):
        outerRadius = min(self.width(), self.height()) / 2 - self._penWidth / 2

        painter = QPainter(self)
        painter.setRenderHint(QPainter.RenderHint.Antialiasing)
        pen = QPen()
        pen.setWidth(self._penWidth)
        painter.setPen(pen)

        painter.save()
        painter.setBrush(Qt.BrushStyle.NoBrush)
        self._bgColor = QColor(self._bgColor)
        painter.setPen(QPen(self._bgColor, self._penWidth))
        painter.drawEllipse(QRectF(self.width() / 2 - outerRadius, self.height() / 2 - outerRadius,
                            outerRadius * 2, outerRadius * 2))
        painter.restore()

        painter.save()
        self._progressColor = QColor(self._progressColor)
        pen = QPen(self._progressColor, self._penWidth)
        pen.setCapStyle(Qt.PenCapStyle.RoundCap)
        painter.setPen(pen)
        path = QPainterPath()
        angle = self._startAngle + (self._endAngle - self._startAngle) * (self._value - self._minimum) / (
                self._maximum - self._minimum)
        path.arcMoveTo(self.width() / 2 - outerRadius, self.height() / 2 - outerRadius,
                       outerRadius * 2, outerRadius * 2, self._startAngle)
        path.arcTo(self.width() / 2 - outerRadius, self.height() / 2 - outerRadius,
                   outerRadius * 2, outerRadius * 2, self._startAngle, angle - self._startAngle)
        painter.drawPath(path)
        painter.restore()

        painter.save()
        painter.setFont(self._font)

        self._textColor = QColor(self._textColor)
        painter.setBrush(self._textColor)

        painter.setPen(self._textColor)
        textRect = QRectF(0, 0, outerRadius * 2, outerRadius * 2)
        textRect.moveCenter(QPointF(self.width() / 2, self.height() / 2))
        painter.drawText(textRect, Qt.AlignmentFlag.AlignCenter, self._formatStr.format(math.ceil(
            (self._value - self._minimum) / (self._maximum - self._minimum) * 100)))
        painter.restore()

    def sizeHint(self):
        fontMetrics = QFontMetrics(self._font)
        textSize = fontMetrics.size(Qt.TextFlag.TextSingleLine, self._formatStr.format(self._maximum))
        diameter = max(textSize.width(), textSize.height()) + self._penWidth + 20
        return QSize(diameter, diameter)

    def minimumSizeHint(self):
        return QSize(10, 10)


# -*- coding:utf-8 -*-
# @time:2023/2/1316:05
# @author:LX
# @file:qtUic.py
# @software:PyCharm
from PyQtGuiLib.header.versions import PYQT_VERSIONS

if PYQT_VERSIONS == "PyQt5":
    from PyQt5 import uic

if PYQT_VERSIONS == "PyQt6":
    from PyQt6 import uic

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtCore import QFile
    from PySide2.QtUiTools import QUiLoader

if PYQT_VERSIONS == "PySide6":
    from PySide6.QtCore import QFile
    from PySide6.QtUiTools import QUiLoader


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QWidget,
    QHBoxLayout,
    QVBoxLayout,
    QFormLayout,
    QLabel,
    QLineEdit,
    QPushButton,
    QSpinBox,
    QSlider,
    qt,
    Signal,
    QColor
)

'''
    调色板框架
'''

from PyQtGuiLib.core.palettes.colorHsv import ColorRect,ColorWheel


class PaletteFrame(QWidget):
    rgbaChange = Signal(tuple)
    # hsvChange = Signal(tuple)
    nameChange = Signal(str)
    clickColor = Signal(tuple)

    Rect = "ColorRect"
    Wheel = "ColorWheel"


    def __init__(self,*args,shape="ColorRect",**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(480,340)

        # 占位窗口
        self.placeholderWidget = QWidget()
        self.placeholderWidget.setStyleSheet('''
background-color: rgb(19, 19, 19);
        ''')

        # 色块窗口
        if shape == PaletteFrame.Wheel:
            self.colorLumpWidget = ColorWheel()
        else:
            self.colorLumpWidget = ColorRect()

        self.Init()
        self.myEvent()


    def Init(self):
        self.hboxLayout = QHBoxLayout(self)
        self.hboxLayout.setSpacing(2)
        self.hboxLayout.setContentsMargins(0,0,0,0)

        self.leftWidget = QWidget(self)
        self.rightWidget = QWidget(self)
        self.leftWidget.setObjectName("leftWidget")
        self.rightWidget.setObjectName("rightWidget")
        self.hboxLayout.addWidget(self.leftWidget)
        self.hboxLayout.addWidget(self.rightWidget)
        
        # ----
        self.vboxLayout = QVBoxLayout(self.leftWidget)
        self.vboxLayout.setSpacing(2)
        self.vboxLayout.setContentsMargins(0,0,0,0)

        self.lucency = QWidget()  # 设置透明滚动条的窗口
        self.lucency.setObjectName("lucency")
        if self.isColorLump():
            self.placeholderWidget = self.colorLumpWidget
        self.vboxLayout.addWidget(self.placeholderWidget)
        self.vboxLayout.addWidget(self.lucency)

        # --------------

        self.label_r,self.label_g,self.label_b,self.label_a,self.label_bin = [
            QLabel("红(R)"),
            QLabel("绿(G)"),
            QLabel("蓝(B)"),
            QLabel("透(A)"),
            QLabel("十六"),
        ]
        self.lineedit_r, self.lineedit_g, self.lineedit_b, self.lineedit_a,self.lineedit_bin = [
            QSpinBox(),QSpinBox(),
            QSpinBox(),QSpinBox(),QLineEdit()
        ]
        for line in [self.lineedit_r,self.lineedit_g,self.lineedit_b,self.lineedit_a]:
            line.setMaximum(255)
            line.setEnabled(False)
        self.lineedit_a.setValue(255)
        self.formLayout = QFormLayout(self.rightWidget)
        self.formLayout.addRow(self.label_r,self.lineedit_r)
        self.formLayout.addRow(self.label_g,self.lineedit_g)
        self.formLayout.addRow(self.label_b,self.lineedit_b)
        self.formLayout.addRow(self.label_a,self.lineedit_a)
        self.formLayout.addRow(self.label_bin,self.lineedit_bin)
        self.colorButton = QPushButton("获取颜色")
        self.formLayout.setWidget(self.formLayout.rowCount(),QFormLayout.SpanningRole,self.colorButton)

        # ----
        self.lucencyHLayout = QHBoxLayout(self.lucency)
        self.lucencyHLayout.setSpacing(1)
        self.t = QLabel("透明")
        self.slider = QSlider()
        self.slider.setMaximum(255)
        self.slider.setOrientation(qt.Horizontal)
        self.s_num = QSpinBox()
        self.s_num.setMaximum(255)
        self.slider.setValue(255)
        self.s_num.setValue(255)
        self.lucencyHLayout.addWidget(self.t)
        self.lucencyHLayout.addWidget(self.slider)
        self.lucencyHLayout.addWidget(self.s_num)

    def updateSize(self):
        r_w = 130
        l_w = self.width()-r_w
        self.leftWidget.setMaximumWidth(l_w)
        self.rightWidget.setMaximumWidth(r_w)

        d_h = 80
        u_h = self.height() - d_h
        self.placeholderWidget.setMaximumHeight(u_h)
        self.lucency.setMaximumHeight(d_h)

    def isColorLump(self)->bool:
        if self.colorLumpWidget:
            return True
        return False

    # 事件
    def myEvent(self):
        self.slider.valueChanged.connect(lambda v:self.slider_event(v,"QSpinBox"))
        self.s_num.valueChanged.connect(lambda v:self.slider_event(v,"QSlider"))
        #
        if self.isColorLump():
            self.placeholderWidget.rgbaChange.connect(self.spbox_event)
            self.placeholderWidget.nameChange.connect(self.lineedit_edit_event)
            self.colorButton.clicked.connect(self.click_color_event)

    # 点击获取颜色
    def click_color_event(self):
        self.clickColor.emit(self.getRGBA())

    def getRGBA(self)->tuple:
        r = self.lineedit_r.text()
        g = self.lineedit_g.text()
        b = self.lineedit_b.text()
        a = self.lineedit_a.text()
        rgba = r,g,b,a
        return rgba

    # 发送 十六进制 颜色
    def lineedit_edit_event(self,color_name):
        self.lineedit_bin.setText(color_name)
        self.nameChange.emit(color_name)

    # 元祖 转 QColor
    def tupleToQColor(self,arga:tuple):
        return QColor(*arga)

    # spbox事件
    def spbox_event(self,rgba):
        r,g,b,a = rgba
        self.lineedit_r.setValue(r)
        self.lineedit_g.setValue(g)
        self.lineedit_b.setValue(b)
        # 发送信号
        self.rgbaChange.emit(rgba)

    # 滚动条事件
    def slider_event(self,v:int,obj_str:str):
        if obj_str == "QSpinBox":
            self.s_num.setValue(v)

        if obj_str == "QSlider":
            self.slider.setValue(v)

        if self.isColorLump():
            self.placeholderWidget.setAlpha(v)
            self.lineedit_a.setValue(v)
            r = self.lineedit_r.text()
            g = self.lineedit_g.text()
            b = self.lineedit_b.text()
            rgba = r,g,b,v
            self.rgbaChange.emit(rgba)
            self.update()

    def resizeEvent(self, event) -> None:
        self.updateSize()
        super().resizeEvent(event)

if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = PaletteFrame(shape=PaletteFrame.Rect)
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/4/1910:42
# @author:LX
# @file:test_animation.py
# @software:PyCharm

from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QPoint,
    QPushButton,
    QSpinBox
)

from PyQtGuiLib.animation import Animation,ParallelAnimationGroup


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,600)


        self.btn = QPushButton("在5秒内完成倒计时",self)
        self.btn.resize(120,60)
        self.btn.move(30,30)
        self.btn.setStyleSheet('''
QPushButton{
background-color: rgb(85, 170, 127);
font-size:10px;
}
        ''')

        self.stopbtn = QPushButton("暂停",self)


        self.ani = Animation()
        self.ani.addAni(self.btn.pos(),QPoint(300,300),courseFunc=self.btn.move,duration=5000,loopCount=-1)

        self.ani.start()

        self.stopbtn.clicked.connect(self.test)

    def test(self):
        if self.ani.state() == Animation.START:
            self.ani.paused()
        else:
            self.ani.resume()


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding: utf-8 -*-

# self implementation generated from reading ui file 'qssFile.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


import sys
from PyQt5.QtWidgets import QApplication, QWidget
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQtGuiLib.styles.qssFile.image import image_rc


class QSSFile(QWidget):
    def __init__(self, *args,**kwargs) -> None:
        super().__init__(*args,**kwargs)
        self.setupUi()
    
    def setupUi(self):
        self.setObjectName("self")
        self.setEnabled(True)
        self.resize(1232, 797)
        self.setStyleSheet("*{\n"
"    background-color: rgb(50, 50, 50);\n"
"    color:rgb(220, 220, 220);\n"
"    font: 12pt \"黑体\";\n"
"}\n"
"/*---------------------*/\n"
"QScrollBar:horizontal{\n"
"    padding:0px;\n"
"    max-height:12px;\n"
"    padding:2px;\n"
"}\n"
"QScrollBar:vertical{\n"
"    padding:0px;\n"
"    max-width:12px;\n"
"    padding:2px;\n"
"}\n"
"QScrollBar::handle{\n"
"background-color: rgb(39, 39, 39);\n"
"border-radius:4%;\n"
"\n"
"}\n"
"QScrollBar::handle:hover{\n"
"background-color: rgb(72, 72, 72);\n"
"border:1px solid rgb(149, 149, 149);\n"
"}\n"
"QScrollBar::add-page,QScrollBar::sub-page {\n"
"    background:rgb(57, 57, 57);\n"
"}\n"
"QScrollBar::sub-line,QScrollBar::add-line {\n"
"    background:none;\n"
"}")
        self.pushButton = QtWidgets.QPushButton(self)
        self.pushButton.setGeometry(QtCore.QRect(30, 50, 141, 51))
        self.pushButton.setStyleSheet("QPushButton{\n"
"background-color: rgb(8, 8, 8);\n"
"border:2px solid rgb(230, 230, 230);\n"
"color:rgb(220, 220, 220);\n"
"border-radius:6%;\n"
"}\n"
"QPushButton:hover{\n"
"background-color: rgb(0, 0, 0);\n"
"}\n"
"QPushButton:pressed{\n"
"background-color:rgb(50, 50, 50);\n"
"}")
        self.pushButton.setObjectName("pushButton")
        self.radioButton = QtWidgets.QRadioButton(self)
        self.radioButton.setGeometry(QtCore.QRect(40, 200, 131, 51))
        self.radioButton.setStyleSheet("QRadioButton{\n"
"\n"
"}\n"
"QRadioButton:hover{\n"
"}\n"
"QRadioButton:pressed{\n"
"\n"
"}\n"
"QRadioButton::indicator {\n"
"    padding:3px 0px 0px 0px;\n"
"    width: 20px;\n"
"    height: 20px;\n"
"}\n"
"QRadioButton::indicator::unchecked{\n"
"    image: url(:/QRadioButton/QRadioButton/QRadioButton.png);\n"
"}\n"
"QRadioButton::indicator::checked{\n"
"    image: url(:/QRadioButton/QRadioButton/QRadioButton_pressed.png);\n"
"}")
        self.radioButton.setObjectName("radioButton")
        self.checkBox = QtWidgets.QCheckBox(self)
        self.checkBox.setGeometry(QtCore.QRect(40, 280, 111, 21))
        self.checkBox.setStyleSheet("QCheckBox::indicator {\n"
"    padding:3px 0px 0px 0px;\n"
"    width: 20px;\n"
"    height: 20px;\n"
"}\n"
"QCheckBox::indicator::unchecked{ \n"
"    image: url(:/QCheckBox/QCheckBox/QCheckBox.png);\n"
"}\n"
"QCheckBox::indicator::checked{\n"
"    image: url(:/QCheckBox/QCheckBox/QCheckBox_pressed.png);\n"
"}")
        self.checkBox.setObjectName("checkBox")
        self.commandLinkButton = QtWidgets.QCommandLinkButton(self)
        self.commandLinkButton.setGeometry(QtCore.QRect(30, 350, 185, 41))
        self.commandLinkButton.setStyleSheet("QCommandLinkButton{\n"
"background-color: rgb(8, 8, 8);\n"
"border:1px solid rgb(0, 120, 215);\n"
"color:rgb(220, 220, 220);\n"
"border-radius:6%;\n"
"}\n"
"QCommandLinkButton:hover{\n"
"background-color: rgb(0, 0, 0);\n"
"}\n"
"QCommandLinkButton:pressed{\n"
"background-color:rgb(50, 50, 50);\n"
"}")
        self.commandLinkButton.setObjectName("commandLinkButton")
        self.tableWidget = QtWidgets.QTableWidget(self)
        self.tableWidget.setGeometry(QtCore.QRect(270, 200, 261, 291))
        self.tableWidget.setStyleSheet("QTableView{\n"
"outline: 0px;\n"
"background-color:rgb(33, 33, 33);\n"
"gridline-color:rgb(125, 125, 125);\n"
"}\n"
"QTableView QHeaderView,QTableView QHeaderView::section, QTableView QTableCornerButton::section {\n"
"background-color:rgb(0, 0, 0);\n"
"color:rgb(175, 175, 175);\n"
"}\n"
"QTableView QHeaderView::section::pressed{\n"
"color:rgb(207, 207, 103);\n"
"}\n"
"QTableView QTableCornerButton::section{\n"
"background-color: rgb(0, 0, 0);\n"
"}\n"
"QHeaderView::section, QTableCornerButton:section {\n"
"    padding: 3px;\n"
"    margin: 0px;\n"
"    border: 1px solid gray;\n"
"    border-left-width: 0px;\n"
"    border-right-width: 1px;\n"
"    border-top-width: 0px;\n"
"    border-bottom-width: 1px;\n"
"}\n"
"QTableView::indicator{\n"
"background-color: rgb(255, 170, 0);\n"
"}\n"
"QTableView::indicator:checked{\n"
"background-color:rgb(33, 33, 33);\n"
"}\n"
"QTableView::item{\n"
"padding:0px;\n"
"border:0px;\n"
"}\n"
"QTableView::item:selected{\n"
"    background-color:#000;\n"
"}\n"
"QTableView::item:hover{\n"
"background-color: rgb(86, 86, 86);\n"
"}\n"
"\n"
"")
        self.tableWidget.setObjectName("tableWidget")
        self.tableWidget.setColumnCount(3)
        self.tableWidget.setRowCount(3)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(2, item)
        self.listWidget_2 = QtWidgets.QListWidget(self)
        self.listWidget_2.setGeometry(QtCore.QRect(280, 40, 261, 131))
        self.listWidget_2.setStyleSheet("QListView {\n"
"outline: 0px;\n"
"background-color: rgb(2, 2, 2);\n"
"color: #FFFFFF;\n"
"border: 1px solid #666666;\n"
"}\n"
"QListView::item:hover{\n"
"padding:0px 0px 0px 15px;\n"
"color:rgb(255, 255, 255);\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0.5625, x2:0.994318, y2:0.614, stop:0 rgba(0, 0, 0, 255), stop:0.909091 rgba(73, 73, 73, 255));\n"
"}\n"
"QListView::item {\n"
"background-color: rgb(2, 2, 2);\n"
"color: rgb(143, 143, 143);\n"
"padding: 5px;\n"
"border-bottom: 1px solid #666666;\n"
"}\n"
"QListView::item:selected {\n"
"padding:0px 0px 0px 15px;\n"
"color:rgb(255, 255, 255);\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0.5625, x2:0.994318, y2:0.614, stop:0 rgba(0, 0, 0, 255), stop:0.909091 rgba(73, 73, 73, 255));\n"
"}")
        self.listWidget_2.setObjectName("listWidget_2")
        item = QtWidgets.QListWidgetItem()
        self.listWidget_2.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidget_2.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidget_2.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidget_2.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidget_2.addItem(item)
        self.toolButton_2 = QtWidgets.QToolButton(self)
        self.toolButton_2.setGeometry(QtCore.QRect(30, 130, 191, 51))
        self.toolButton_2.setStyleSheet("QToolButton {\n"
"    border-radius:6%;\n"
"    background-color: #1E1E1E; \n"
"    color: #FFFFFF; \n"
"    border: 1px solid #2F2F2F; \n"
"    padding: 5px;\n"
"}\n"
"\n"
"QToolButton:hover {\n"
"    background-color: rgb(18, 18, 18);\n"
"}\n"
"\n"
"QToolButton:pressed {\n"
"    background-color:#1E1E1E; \n"
"}\n"
"")
        self.toolButton_2.setObjectName("toolButton_2")
        self.treeWidget = QtWidgets.QTreeWidget(self)
        self.treeWidget.setGeometry(QtCore.QRect(570, 40, 261, 181))
        self.treeWidget.setStyleSheet("QTreeView{\n"
"    background-color: rgb(33, 33, 33);\n"
"    color:rgb(188, 188, 188);\n"
"}\n"
"QTreeView QHeaderView,QTreeView QHeaderView::section{\n"
"background-color: rgb(0, 0, 0);\n"
"color:rgb(175, 175, 175);\n"
"}\n"
"QTreeView::item:hover{\n"
"background-color:transparent;\n"
"}\n"
"QTreeView::item:selected{\n"
"background-color:rgb(121, 121, 121);\n"
"color: rgb(255, 255, 255);\n"
"}\n"
"QTreeView::branch:selected{\n"
"    background-color:rgb(121, 121, 121);\n"
"}")
        self.treeWidget.setRootIsDecorated(True)
        self.treeWidget.setUniformRowHeights(False)
        self.treeWidget.setItemsExpandable(True)
        self.treeWidget.setAnimated(False)
        self.treeWidget.setObjectName("treeWidget")
        item_0 = QtWidgets.QTreeWidgetItem(self.treeWidget)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_0 = QtWidgets.QTreeWidgetItem(self.treeWidget)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        self.treeWidget.header().setCascadingSectionResizes(False)
        self.treeWidget.header().setDefaultSectionSize(200)
        self.treeWidget.header().setHighlightSections(False)
        self.groupBox = QtWidgets.QGroupBox(self)
        self.groupBox.setGeometry(QtCore.QRect(580, 260, 231, 141))
        self.groupBox.setStyleSheet("QGroupBox {\n"
"border:1px solid rgb(118, 118, 118);\n"
"border-radius:5px;\n"
"background-color: rgb(26, 26, 26);\n"
"}\n"
"")
        self.groupBox.setObjectName("groupBox")
        self.toolBox = QtWidgets.QToolBox(self)
        self.toolBox.setGeometry(QtCore.QRect(900, 60, 241, 131))
        self.toolBox.setStyleSheet("QToolBox::tab {\n"
"    background-color: rgb(90, 90, 90);\n"
"    border-radius:3%;\n"
"    padding:5px;\n"
"}\n"
"\n"
"QToolBox::tab:selected{\n"
"    font: italic;\n"
"    color: white;\n"
"}")
        self.toolBox.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.toolBox.setObjectName("toolBox")
        self.page = QtWidgets.QWidget()
        self.page.setGeometry(QtCore.QRect(0, 0, 241, 71))
        self.page.setObjectName("page")
        self.toolBox.addItem(self.page, "")
        self.page_2 = QtWidgets.QWidget()
        self.page_2.setGeometry(QtCore.QRect(0, 0, 241, 71))
        self.page_2.setObjectName("page_2")
        self.toolBox.addItem(self.page_2, "")
        self.tabWidget = QtWidgets.QTabWidget(self)
        self.tabWidget.setGeometry(QtCore.QRect(840, 250, 331, 181))
        self.tabWidget.setStyleSheet("QTabWidget::pane {\n"
"}\n"
"QTabWidget QWidget{\n"
"background-color: rgb(20, 20, 20);\n"
"}\n"
"QTabWidget QTabBar::tab{\n"
"background-color: rgb(20, 20, 20);\n"
"min-width: 20ex;\n"
"padding: 5px;\n"
"}\n"
"QTabBar::tab:selected{\n"
"color: rgb(180, 239, 255);\n"
"}\n"
"\n"
"QTabBar::tab:!selected{\n"
"background-color: rgb(65, 65, 65);\n"
"}")
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.tabWidget.addTab(self.tab_2, "")
        self.comboBox = QtWidgets.QComboBox(self)
        self.comboBox.setEnabled(True)
        self.comboBox.setGeometry(QtCore.QRect(30, 550, 211, 51))
        self.comboBox.setStyleSheet("QComboBox {\n"
"background-color: rgb(0, 0, 0);\n"
"border:1px solid rgb(255, 255, 255);\n"
"border-bottom:none;\n"
"border-left:none;\n"
"border-right:none;\n"
"    color: rgb(182, 182, 182);\n"
"    border-radius: 1px;\n"
"    padding: 1px 18px 1px 3px;\n"
"    min-width: 6em;\n"
"}\n"
"QComboBox:editable{\n"
"\n"
"}\n"
"QComboBox::drop-down{\n"
"      width: 30px;\n"
"    padding-right:8px;\n"
"    image: url(:/QComboBox/QComboBox/down-arrow.png);\n"
"}\n"
"QComboBox::down-arrow{\n"
"\n"
"    \n"
"}\n"
"QComboBox QAbstractItemView{\n"
"background-color: rgb(0, 0, 0);\n"
"border:none;\n"
"outline: 0px;\n"
"selection-background-color:rgb(0, 0, 0);\n"
"selection-color:rgb(0, 255, 255);\n"
"}")
        self.comboBox.setEditable(True)
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.fontComboBox = QtWidgets.QFontComboBox(self)
        self.fontComboBox.setGeometry(QtCore.QRect(30, 640, 211, 41))
        self.fontComboBox.setStyleSheet("QFontComboBox {\n"
"    border:2px solid rgb(103, 103, 103);\n"
"    border-radius: 5px;\n"
"    padding: 1px 18px 1px 3px;\n"
"    min-width: 6em;\n"
"}\n"
"QFontComboBox QAbstractItemView{\n"
"outline: 0px;\n"
"selection-background-color: rgb(90, 90, 90);\n"
"}")
        self.fontComboBox.setObjectName("fontComboBox")
        self.lineEdit = QtWidgets.QLineEdit(self)
        self.lineEdit.setGeometry(QtCore.QRect(290, 520, 241, 51))
        self.lineEdit.setStyleSheet("QLineEdit{\n"
"border:2px solid rgb(0, 0, 0);\n"
"border-top:none;\n"
"border-left:none;\n"
"border-right:none;\n"
"}\n"
"QLineEdit:hover{\n"
"border:2px solid qlineargradient(spread:pad, x1:0.012, y1:0.556818, x2:1, y2:0.573864, stop:0 rgba(110, 203, 205, 255), stop:0.965909 rgba(67, 91, 95, 255));\n"
"border-top:none;\n"
"border-left:none;\n"
"border-right:none;\n"
"}")
        self.lineEdit.setObjectName("lineEdit")
        self.textEdit = QtWidgets.QTextEdit(self)
        self.textEdit.setGeometry(QtCore.QRect(290, 590, 231, 81))
        self.textEdit.setStyleSheet("QTextEdit{\n"
"border:1px solid rgb(0, 0, 0);\n"
"border-radius: 3px;\n"
"}\n"
"QTextEdit:hover{\n"
"    border:1px solid rgb(0, 85, 255);\n"
"}")
        self.textEdit.setObjectName("textEdit")
        self.plainTextEdit = QtWidgets.QPlainTextEdit(self)
        self.plainTextEdit.setGeometry(QtCore.QRect(290, 710, 241, 71))
        self.plainTextEdit.setStyleSheet("QPlainTextEdit{\n"
"border:1px solid rgb(0, 0, 0);\n"
"border-radius: 4%;\n"
"    background-color: rgb(66, 66, 66);\n"
"}\n"
"QPlainTextEdit:hover{\n"
"border:1px solid rgb(109, 109, 109);\n"
"}")
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.spinBox = QtWidgets.QSpinBox(self)
        self.spinBox.setGeometry(QtCore.QRect(570, 480, 151, 41))
        self.spinBox.setObjectName("spinBox")
        self.doubleSpinBox = QtWidgets.QDoubleSpinBox(self)
        self.doubleSpinBox.setGeometry(QtCore.QRect(570, 560, 141, 41))
        self.doubleSpinBox.setObjectName("doubleSpinBox")
        self.progressBar = QtWidgets.QProgressBar(self)
        self.progressBar.setGeometry(QtCore.QRect(780, 490, 331, 31))
        self.progressBar.setStyleSheet("QProgressBar {\n"
"    border: 2px solid rgb(0, 0, 0);\n"
"    border-radius: 5px;\n"
"}\n"
"\n"
"QProgressBar::chunk {\n"
"    border: 2px solid rgb(72, 72, 72);\n"
"    width: 20px;\n"
"}")
        self.progressBar.setProperty("value", 100)
        self.progressBar.setAlignment(QtCore.Qt.AlignCenter)
        self.progressBar.setObjectName("progressBar")
        self.lcdNumber = QtWidgets.QLCDNumber(self)
        self.lcdNumber.setGeometry(QtCore.QRect(760, 560, 64, 23))
        self.lcdNumber.setDigitCount(5)
        self.lcdNumber.setProperty("intValue", 41)
        self.lcdNumber.setObjectName("lcdNumber")

        self.retranslateUi()
        self.toolBox.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(self)

    def retranslateUi(self):
        _translate = QtCore.QCoreApplication.translate
        self.setWindowTitle(_translate("self", "self"))
        self.pushButton.setText(_translate("self", "PushButton"))
        self.radioButton.setText(_translate("self", "RadioButton"))
        self.checkBox.setText(_translate("self", "CheckBox"))
        self.commandLinkButton.setText(_translate("self", "CommandLinkButton"))
        item = self.tableWidget.verticalHeaderItem(0)
        item.setText(_translate("self", "新建行"))
        item = self.tableWidget.verticalHeaderItem(1)
        item.setText(_translate("self", "新建行"))
        item = self.tableWidget.verticalHeaderItem(2)
        item.setText(_translate("self", "新建行"))
        item = self.tableWidget.horizontalHeaderItem(0)
        item.setText(_translate("self", "新建列"))
        item = self.tableWidget.horizontalHeaderItem(1)
        item.setText(_translate("self", "新建列"))
        item = self.tableWidget.horizontalHeaderItem(2)
        item.setText(_translate("self", "新建列"))
        __sortingEnabled = self.listWidget_2.isSortingEnabled()
        self.listWidget_2.setSortingEnabled(False)
        item = self.listWidget_2.item(0)
        item.setText(_translate("self", "新建项目"))
        item = self.listWidget_2.item(1)
        item.setText(_translate("self", "新建项目"))
        item = self.listWidget_2.item(2)
        item.setText(_translate("self", "新建项目"))
        item = self.listWidget_2.item(3)
        item.setText(_translate("self", "新建项目"))
        item = self.listWidget_2.item(4)
        item.setText(_translate("self", "新建项目"))
        self.listWidget_2.setSortingEnabled(__sortingEnabled)
        self.toolButton_2.setText(_translate("self", "..."))
        self.treeWidget.setSortingEnabled(False)
        self.treeWidget.headerItem().setText(0, _translate("self", "属性"))
        self.treeWidget.headerItem().setText(1, _translate("self", "值"))
        __sortingEnabled = self.treeWidget.isSortingEnabled()
        self.treeWidget.setSortingEnabled(False)
        self.treeWidget.topLevelItem(0).setText(0, _translate("self", "新建项目"))
        self.treeWidget.topLevelItem(0).child(0).setText(0, _translate("self", "新建子项目"))
        self.treeWidget.topLevelItem(0).child(1).setText(0, _translate("self", "新建子项目"))
        self.treeWidget.topLevelItem(1).setText(0, _translate("self", "新建项目"))
        self.treeWidget.topLevelItem(1).child(0).setText(0, _translate("self", "新建子项目"))
        self.treeWidget.topLevelItem(1).child(1).setText(0, _translate("self", "新建子项目"))
        self.treeWidget.setSortingEnabled(__sortingEnabled)
        self.groupBox.setTitle(_translate("self", "分组"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.page), _translate("self", "第一页"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.page_2), _translate("self", "第二页"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("self", "Tab 1"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("self", "Tab 2"))
        self.comboBox.setItemText(0, _translate("self", "新建项目"))
        self.comboBox.setItemText(1, _translate("self", "新建项目"))
        self.comboBox.setItemText(2, _translate("self", "新建项目"))
        self.lineEdit.setText(_translate("self", "dsad"))
        self.textEdit.setHtml(_translate("self", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'黑体\'; font-size:12pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">dsad</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">das</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">d</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">as</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">d</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">as</p></body></html>"))


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = QSSFile()
    win.show()

    sys.exit(app.exec_())
    


# -*- coding:utf-8 -*-
# @time:2023/1/3013:03
# @author:LX
# @file:qtSip.py
# @software:PyCharm
from PyQtGuiLib.header.versions import PYQT_VERSIONS

if PYQT_VERSIONS == "PyQt5":
    from PyQt5.sip import delete


if PYQT_VERSIONS == "PyQt6":
    from PyQt6.sip import delete

if PYQT_VERSIONS == "PySide2":
    try:
        from PySide2.sip import delete
    except:
        pass

if PYQT_VERSIONS == "PySide6":
    try:
        from PySide6.sip import delete
    except:
        pass


# -*- coding:utf-8 -*-
# @time:2023/6/818:14
# @author:LX
# @file:utility.py
# @software:PyCharm
from PyQtGuiLib.header import (
    QImage,
    QPixmap,
    QSize
)

from typing import TypeVar

Head_Type = TypeVar("Head_Type",str,bytes)


def imageToPix(data:Head_Type,size):
    image = QImage()
    if isinstance(data, bytes):
        image.loadFromData(data)
    elif isinstance(data, str):
        image.load(data)
    pix = QPixmap()
    fimage = pix.fromImage(image)
    return fimage.scaled(size)



# -*- coding:utf-8 -*-
# @time:2023/6/518:19
# @author:LX
# @file:headImage.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QLabel,
    QScrollArea,
    QVBoxLayout,
    Qt,
    QImage,
    QPixmap
)
from PyQtGuiLib.core.charRooms.utility import imageToPix,Head_Type


class HeadImage(QLabel):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

    def setHeadImage(self,data:Head_Type):
        self.setPixmap(imageToPix(data,self.size()))



# -*- coding:utf-8 -*-
# @time:2023/4/1110:30
# @author:LX
# @file:listTemplateWindow.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QListWidgetItem,
    QIcon,
    QSize,
    QPropertyAnimation,
    QGridLayout,
    qt,
    Qt,
    QMenu,
    QAction,
    QPoint,
    QGraphicsDropShadowEffect,
    QColor,
    QResizeEvent,
    QShortcut,
    QKeySequence,
    QVBoxLayout
)
from random import randint
import typing

from PyQtGuiLib.templateWindow.UI.listTemplateWindowUI import ListTemplateWindowUI


# 文档外框
class DocumentFrame(QWidget):
    def __init__(self, widget:QWidget,st,index,documents:list):
        super().__init__()
        self.resize(500,500)
        self.vboy = QVBoxLayout(self)


        self.widget = widget
        self.st = st
        self.index = index
        self.documents = documents
        print(st,index)

        self.vboy.addWidget(self.widget)

    def closeEvent(self, e) -> None:
        self.st.insertWidget(self.index,self.widget)
        self.documents.remove(self.widget)
        super().closeEvent(e)

class ListTemplateWindow(ListTemplateWindowUI):
    def __init__(self,*args,**kwargs):
        # 头像状态记录
        self.head_suspension = {
            "isSuspension": False
        }

        super().__init__(*args,**kwargs)

        # 伸缩标记,伸缩值
        self.__flexible_flag = True
        self.__flexible_value = (260,60)

        # 模块图标大小
        self.listWidget.setIconSize(QSize(50,50))

        # 文档窗口存储
        self.documents = []

        self.__ani = QPropertyAnimation(self)
        self.__ani.setTargetObject(self.listWidget)
        self.__ani.setPropertyName(b"size")
        self.__ani.setDuration(600)

        self.setContextMenuPolicy(Qt.CustomContextMenu)

        self.__shadow = QGraphicsDropShadowEffect(self)
        self.__shadow.setOffset(0,0)
        self.__shadow.setBlurRadius(30)
        self.__shadow.setColor(QColor("#8ab2e7"))
        self.btn_head_picture.setGraphicsEffect(self.__shadow)

        # 菜单列表
        self.__menus = []
        self.__meun_list = []

        self.__myEvent()
        self.__builtInMenu()
        self.__shortcutKey()

    def __builtInMenu(self):
        self.addMenus([{
            "text":"隐藏/显示菜单(内置功能)",
            "call":self.sidebar_event
            },
            {
                "text":"头像悬浮(内置功能)",
                "call":self.__suspension
            }
        ])

    # 移除头部,头像悬浮功能
    def __suspension(self):
        scale = 0.8  # 缩放倍率

        if self.head_suspension["isSuspension"]:
            self.btn_head_picture.setParent(None)
            w = int(self.btn_head_picture.width() / scale)
            h = int(self.btn_head_picture.height() / scale)
            self.btn_head_picture.setFixedSize(w, h)
            self.qss_head_picture.selector("QPushButton").updateAttr("border-radius",
                                                                     "{}px".format(self.btn_head_picture.width() // 2))
            iw = int(self.btn_head_picture.iconSize().width() / scale)
            ih = int(self.btn_head_picture.iconSize().height() / scale)
            self.btn_head_picture.setIconSize(QSize(iw, ih))
            self.horizontalLayout.addWidget(self.btn_head_picture)
            self.widget_head.show()
            self.head_suspension["isSuspension"] = False
            self.core_widget.setSuspension(False)
            return

        '''
            将头像按钮从布局中移出,在隐藏会整个头部,
            在将头像按钮的父级设置为整个窗口
        '''
        self.horizontalLayout.removeWidget(self.btn_head_picture)
        self.widget_head.hide()
        self.btn_head_picture.setParent(self)
        self.btn_head_picture.show()
        self.btn_head_picture.move(self.width()-self.btn_head_picture.width()+10,10)
        # 样式,图片大小跟随缩小
        w = int(self.btn_head_picture.width()*scale)
        h = int(self.btn_head_picture.height()*scale)
        self.btn_head_picture.setFixedSize(w,h)
        self.qss_head_picture.selector("QPushButton").updateAttr("border-radius","{}px".format(self.btn_head_picture.width() // 2))
        iw = int(self.btn_head_picture.iconSize().width()*scale)
        ih = int(self.btn_head_picture.iconSize().height()*scale)
        self.btn_head_picture.setIconSize(QSize(iw,ih))

        self.head_suspension["isSuspension"] = True
        self.core_widget.setSuspension(True)

    def addMenu(self,item:dict):
        self.__menus.append(item)

    def addMenus(self,items:typing.List[dict]):
        for item in items:
            self.addMenu(item)

    def removeMenu(self,text:str):
        del self.__menus[text]

    def __menu_event(self):
        if not self.__menus:
            return

        self.menu = QMenu(self)
        self.menu.setStyleSheet('''
        QMenu {
        border:none;
        font: 12pt "黑体";
        border-radius:5px;
        padding: 0,0,0,15px;
        }
        QMenu::item:selected{
        background-color:#789ac9;
        }
                ''')

        for act in self.__menus:
            text = act["text"]
            call = act.get("call",None)
            obj = act.get("obj",None)
            if obj is None:
                act["obj"] = QAction(text)
                obj = act["obj"]
                if call:
                    obj.triggered.connect(call)
            self.menu.addAction(obj)

        if self.listWidget.isHidden():
            x = self.btn_head_picture.x() + self.x()
        else:
            x = self.btn_head_picture.x() + self.x() + self.listWidget.width()
        y = self.btn_head_picture.y()+self.y()+self.head_middle_widget.height() + 10

        pos = QPoint(x,y)
        self.menu.popup(pos)

    # 设置头像
    def setHeadPicture(self,path:str,size:tuple=(100,100)):
        self.btn_head_picture.setIconSize(QSize(*size))
        self.btn_head_picture.setIcon(QIcon(path))

    def addItem(self,text:typing.Union[str,QListWidgetItem],widget:QWidget,icon:str=None):
        if isinstance(text,QListWidgetItem):
            if icon:
                text.setIcon(QIcon(icon))
            self.listWidget.addItem(text)
            return

        item = QListWidgetItem()
        item.setText(text)
        if icon:
            item.setIcon(QIcon(icon))
        self.listWidget.addItem(item)
        self.stackedWidget.addWidget(widget)

    # 添加头部窗口
    def addHeadWidget(self,widget:QWidget):
        self.head_middle_vbody.addWidget(widget)

    # 隐藏/显示侧边栏
    def sidebar_event(self):
        if self.listWidget.isHidden():
            self.listWidget.show()
            self.btn_fold.show()
        else:
            self.listWidget.hide()
            self.btn_fold.hide()

    # 通过索引隐藏/显示,某个item
    def setHideItem(self,index:int,b:bool=True):
        item = self.listWidget.item(index) # type:QListWidgetItem
        item.setHidden(b)

    def __ani_event(self):
        if self.stackedWidget.count() < 1:
            return

        self.__ani.setStartValue(self.listWidget.size())
        if self.__flexible_flag:
            self.qss_listwiget.selector("QListView::item:selected").removeAttr("border-right")
            self.__ani.setEndValue(QSize(self.__flexible_value[1],self.listWidget.height()))
            self.__flexible_flag = False
        else:
            self.qss_listwiget.selector("QListView::item:selected").updateAttr("border-right","5px solid #0055ff")
            self.__ani.setEndValue(QSize(self.__flexible_value[0], self.listWidget.height()))
            self.__flexible_flag = True

        self.__ani.valueChanged.connect(lambda v:self.listWidget.setMaximumWidth(v.width()))
        self.__ani.start()

    def __change_st_event(self,item:QListWidgetItem):
        index = self.listWidget.indexFromItem(item).row()
        self.stackedWidget.setCurrentIndex(index)

    def __myEvent(self):
        self.listWidget.itemClicked.connect(self.__change_st_event)
        self.btn_fold.clicked.connect(self.__ani_event)
        self.btn_head_picture.clicked.connect(self.__menu_event)

    # 默认快捷键
    def __shortcutKey(self):
        QShortcut(QKeySequence(self.tr("Ctrl+Q")),self,self.shortcut_ctrl_q)

    def shortcut_ctrl_q(self):
        index = self.stackedWidget.getCursorWidgetIndex()
        widget = self.stackedWidget.popWidget(self.stackedWidget.getCursorWidget())
        pp = DocumentFrame(widget,self.stackedWidget,index,self.documents)
        pp.show()
        self.documents.append(pp)


    def resizeEvent(self, e: QResizeEvent) -> None:
        # 在这里面处理头像悬浮状态下的位置
        if self.head_suspension["isSuspension"]:
            self.btn_head_picture.move(self.width() - self.btn_head_picture.width()-10, 10)
        super().resizeEvent(e)


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = ListTemplateWindow()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())



# -*- coding:utf-8 -*-
# @time:2023/2/1316:17
# @author:LX
# @file:test_uic.py
# @software:PyCharm

from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    loadUic
)

app = QApplication(sys.argv)

ui = loadUic(r"xxx.ui")
ui.show()

if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
    sys.exit(app.exec())
else:
    sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/4/1910:39
# @author:LX
# @file:PropertyAnimation.py
# @software:PyCharm
from PyQtGuiLib.header import (
    QPropertyAnimation,
    QParallelAnimationGroup,
    QSequentialAnimationGroup,
    QObject,
    QColor,
    QSize,
    QPoint
)
import re
import typing
from typing import Any,List,Tuple,Union

from PyQtGuiLib.styles import QssStyleAnalysis


def strToObj(v_str:str)->Union[QColor,Any]:
    v_str = v_str.lower().strip()

    if "rgb" in v_str or "rgba" in v_str:
        color_list = [int(i) for i in re.findall(r"[0-9]{1,3}", v_str)]
        return QColor(*color_list)
    elif "#" == v_str[0]:
        return QColor(v_str)
    elif "px" in v_str or "pt" in v_str:
        px_number = re.findall("^([0-9]*)px|^([0-9]*)pt",v_str)
        if px_number:
            if px_number[0][0]:return int(px_number[0][0])
            else:return int(px_number[0][1])



# 单个动画类
class PropertyAnimation(QPropertyAnimation):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

        self.setTargetObject(QObject())
        self.setDuration(1200)

        self.__call = None
        self.__selector = None
    
    def setStartEndValue(self,sv:Any,ev:Any,atv:Union[List[Any],List[Tuple[float,Any]]]=None):
        self.setStartValue(sv)
        if atv:
            one_e = atv[0]
            if isinstance(one_e, tuple) or isinstance(one_e, list):
                for step, value in atv:
                    self.setKeyValueAt(step, value)
            else:
                mean_time = 1 / len(atv)  # 平均时间
                step = 0.0
                for value in atv:
                    step += mean_time
                    self.setKeyValueAt(step, value)
        self.setEndValue(ev)

    # 在设置选择器的同时创建出qss对象
    def setSelector(self,selector:str,qssObj:QssStyleAnalysis=None):
        self.__selector = selector
        # ----在这里判断是否为QSS属性,如果_qss对象创建过,则直接使用已创建的
        if qssObj is None and self.__isQssPropertyName(self.propertyName()):
            self._qss = QssStyleAnalysis(self.targetObject())
            self._qss.setQSS(self.targetObject().styleSheet())
        else:
            self._qss = qssObj

    # 该方法用来检测_qss是否被创建过,存在则返回
    def qss(self) -> Union[QssStyleAnalysis,bool]:
        if hasattr(self,"_qss"):
            return self._qss
        return False

    def selector(self) -> str:
        return self.__selector

    # 判断 propertyName 是否为 QSS的属性
    def __isQssPropertyName(self,propertyName:bytes)->bool:
        propertyName = propertyName.data().decode()
        if self.targetObject() and self.selector():
            if propertyName not in ["pos","size","geometry","windowOpacity"]:
                return True
        return False

    def setPropertyName(self, propertyName):
        if isinstance(propertyName,str):
            propertyName = propertyName.encode()
        super().setPropertyName(propertyName)

    # 函数执行过程中调用的函数
    def courseFunc(self,call):
        self.__call = call

    def func(self) -> typing.Callable:
        return self.__call

    # 分析this处理返回
    def __analysisThis(self, value: str):
        '''
            对 this 的处理,为了保证this能正确的被处理,请确保设置过动画对象
        '''
        if not self.targetObject():
            return value

        if self.propertyName() == b"size":
            return self.targetObject().size()
        elif self.propertyName() == b"pos":
            return self.targetObject().pos()
        elif self.propertyName() == b"geometry":
            return self.targetObject().rect()
        elif self.propertyName() == b"windowOpacity":
            return self.targetObject().windowOpacity()

    # 处理QSS属性动画
    def __selectorAni(self,Any):
        selector = self._qss.selector(self.selector())
        propertyName = self.propertyName().data().decode()
        if selector.isAttr(propertyName):
            if isinstance(Any, int):
                value = "{}px".format(Any)
            elif isinstance(Any, QColor):
                value = "rgba({},{},{},{})".format(*Any.getRgb())
            self._qss.selector(self.selector()).updateAttr(propertyName, value)

    def updateCurrentValue(self, Any):
        if self.func():
            self.func()(Any)
        elif self.selector(): # 如果给了选择器,则可以视为QSS样式属性
            self.__selectorAni(Any)
        else:
            super().updateCurrentValue(Any)

    def setStartValue(self, value: typing.Any) -> None:
        if isinstance(value, str) and value.lower().strip() == "this":
            value = self.__analysisThis(value)
        elif isinstance(value,str):
            value = strToObj(value)
        super().setStartValue(value)

    def setEndValue(self, value: typing.Any) -> None:
        if isinstance(value, str):
            value = strToObj(value)
        super().setEndValue(value)

    # 动画执行完成的回调函数
    def finishedCall(self,call):
        self.finished.connect(call)

    def valueChanged(self, Any):
        super().valueChanged(Any)

# ===================================================


class ParallelAnimationGroup(QParallelAnimationGroup):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

    def build(self,ani):
        if isinstance(ani.startMode(),ParallelAnimationGroup):
            group = QParallelAnimationGroup()
        else:
            group = QSequentialAnimationGroup()
        for ani in ani.allAnins():
            group.addAnimation(ani)
        self.addAnimation(group)

    def builds(self,anis:list):
        for ani in anis:
            self.build(ani)

    def addAnimations(self,anis:List[PropertyAnimation]):
        for ani in anis:
            self.addAnimation(ani)


class SequentialAnimationGroup(QSequentialAnimationGroup):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)

    def addAnimations(self,anis:List[PropertyAnimation]):
        for ani in anis:
            self.addAnimation(ani)

    def build(self, ani):
        if isinstance(ani.startMode(), ParallelAnimationGroup):
            group = QParallelAnimationGroup()
        else:
            group = QSequentialAnimationGroup()
        for ani in ani.allAnins():
            group.addAnimation(ani)
        self.addAnimation(group)

    def builds(self,anis:list):
        for ani in anis:
            self.build(ani)


# -*- coding:utf-8 -*-
# @time:2023/4/2013:48
# @author:LX
# @file:drawer.py
# @software:PyCharm

from PyQtGuiLib.header import (
    QWidget,
    QPushButton,
    QVBoxLayout,
    QSpacerItem,
    QSizePolicy,
    QScrollArea,
    qt
)

from PyQtGuiLib.animation import Animation

class DrawerItem(QWidget):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.resize(300, 300)

        self.__vboy = QVBoxLayout(self)
        self.__vboy.setSpacing(0)
        self.__vboy.setContentsMargins(0,0,0,0)
        self.setFixedHeight(50)

        self._sp = QSpacerItem(0,0,QSizePolicy.Minimum,QSizePolicy.Expanding)
        self.__flag = False

        self.__duration = 200
        self.__area = 300

        self.setFixedHeight(30)

    def setFixedHeight(self, h: int) -> None:
        self._fh = h
        super().setFixedHeight(h)

    def setDuration(self,duration:int):
        self.__duration =duration

    # 设置展开高度
    def setDevelopedArea(self,area):
        self.__area = area

    def stretch_event(self):
        self.__ani = Animation()
        self.__ani.setStartMode(Animation.Parallel)
        if self.__flag is False:
            self.__ani.addAni(self.btn.height(),self.__area,duration=self.__duration,courseFunc=self.setFixedHeight)
            self.__ani.addAni(self.expansion_widget.height(),self.__area,duration=self.__duration,courseFunc=self.expansion_widget.setFixedHeight)
            self.__flag = True
        else:
            self.__ani.addAni(self.height(),self.btn.height(),duration=self.__duration,courseFunc=self.setFixedHeight)
            self.__ani.addAni(self.expansion_widget.height(), 0,duration=self.__duration, courseFunc=self.expansion_widget.setFixedHeight)
            self.__flag = False
        self.__ani.start()

    def setButton(self,btn):
        self.btn = btn
        self.btn.setMinimumHeight(self._fh)
        self.btn.clicked.connect(self.stretch_event)

    def setWidget(self,widget:QWidget):
        self.expansion_widget = widget
        self.expansion_widget.setFixedHeight(0)
        self.__vboy.addWidget(self.btn)
        self.__vboy.addWidget(self.expansion_widget)
        self.__vboy.addItem(self._sp)


class Drawer(QScrollArea):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)

        self.setWidgetResizable(True)

        self.__core = QWidget()

        self.setWidget(self.__core)

        self._vboy = QVBoxLayout(self.__core)
        self._vboy.setSpacing(0)
        self._vboy.setContentsMargins(0,0,0,0)
        self._sp = QSpacerItem(0, 0, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.setHorizontalScrollBarPolicy(qt.ScrollBarAlwaysOff)
        self.setVerticalScrollBarPolicy(qt.ScrollBarAlwaysOff)

    def addItem(self,item:DrawerItem):
        self._vboy.removeItem(self._sp)
        self._vboy.addWidget(item)
        self._vboy.addItem(self._sp)

    def findItem(self,index:int)->DrawerItem:
        return self._vboy.itemAt(index).widget()

    def removeItem(self,item:DrawerItem):
        self._vboy.removeWidget(item)



# -*- coding:utf-8 -*-
# @time:2023/4/1010:09
# @author:LX
# @file:test.py
# @software:PyCharm
from PyQtGuiLib.header import (
    QApplication,
    PYQT_VERSIONS,
    sys,
    QWidget,
    QPainter,
    QPen,
    QBrush,
    QFont,
    qt,
    Qt,
    QColor,
    QPaintEvent,
    QPushButton,
    QRect,
    QPoint,
    QLine
)

from PyQtGuiLib.animation import Animation
from PyQtGuiLib.styles import SuperPainter

class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(600,600)
        self.painter = SuperPainter()


        self.btn = QPushButton(self)
        self.btn.setText("按钮")
        self.btn.clicked.connect(self.test)


    def test(self):
        rent = self.painter.virtualObj("rrent")
        print(rent)
        if rent.isHide():
            rent.setHide(False)
        else:
            rent.setHide(True)
        self.update()

    def paintEvent(self, e:QPaintEvent) -> None:
        self.painter.begin(self)
        self.painter.setRenderHints(qt.Antialiasing | qt.SmoothPixmapTransform | qt.TextAntialiasing)

        self.painter.drawRect(50,0,50,self.height(),virtualObjectName="rrent",brushAttr={"c":"green"})


        self.painter.end()


'''

'''

if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()

    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())



# -*- coding:utf-8 -*-
# @time:2023/6/2517:32
# @author:LX
# @file:test_p_ani.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QPoint,
    QPushButton,
    QSpinBox,
    QRect,
    QObject
)

from PyQtGuiLib.animation import Animation
from PyQtGuiLib.styles import SuperPainter

'''
    SuperPainter + Animation 实现图形动画
'''

class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,600)

        self.painter = SuperPainter(self)

        self.btn = QPushButton(self)
        self.btn.setText("执行painter动画")
        self.btn.clicked.connect(self.test_ani)

    def test_ani(self):
        vobj = self.painter.virtualObj("arect")
        print(vobj.getVirtualArgs())
        self.ani = Animation()
        self.ani.addAni(vobj.getVirtualArgs()[-1],100,courseFunc=self.updateRect)
        self.ani.start()

    def updateRect(self,r):
        vobj = self.painter.virtualObj("arect")
        vobj.updateIndexToArgs(2,r)
        self.update()

    def paintEvent(self, e):
        self.painter.begin(self)
        # self.painter.drawRect(50,50,50,50,virtualObjectName="arect")
        # self.painter.drawCursor(50,50,50,50,25,openAttr={"c":"red","w":2},virtualObjectName="arect")
        self.painter.drawRhomboid(100,100,30,brushAttr={"c":"green"},virtualObjectName="arect")
        self.painter.end()


if __name__ == '__main__':
    app = QApplication(sys.argv)

    win = Test()
    win.show()

    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQt5.QtWidgets import QApplication, QListWidget, QListWidgetItem

app = QApplication([])

list_widget = QListWidget()

# list_widget.setro
list_widget.setFlow(QListWidget.LeftToRight)
list_widget.setResizeMode(QListWidget.Adjust)

for i in range(10):
    item = QListWidgetItem(f"Item {i}")
    list_widget.addItem(item)

list_widget.show()
app.exec_()



from PyQtGuiLib.header.versions import PYQT_VERSIONS

if PYQT_VERSIONS == "PyQt5":
    from PyQt5.QtGui import *
    from PyQt5.QtGui import QGuiApplication as DesktopWidget

if PYQT_VERSIONS == "PyQt6":
    from PyQt6.QtGui import *
    from PyQt6.QtGui import QGuiApplication as DesktopWidget

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtGui import *
    from PySide2.QtGui import QGuiApplication as DesktopWidget

if PYQT_VERSIONS == "PySide6":
    from PySide6.QtGui import *
    from PySide6.QtGui import QGuiApplication as DesktopWidget